@@ -1,11 +1,14 @@
 import typing as _typing
+
 import yaml as _yaml
 
 from kuber import versioning as _versioning
-from kuber.interface import CommandAction  # noqa
 from kuber.definitions import Collection  # noqa
 from kuber.definitions import Definition  # noqa
+from kuber.definitions import OptionalPathLike  # noqa
+from kuber.definitions import PathLike  # noqa
 from kuber.definitions import Resource  # noqa
+from kuber.interface import CommandAction  # noqa
 from kuber.kube_api import get_version_from_cluster  # noqa
 from kuber.kube_api import load_access_config  # noqa
 from kuber.management import ResourceBundle
@@ -19,7 +22,7 @@ from kuber.management.creation import new_resource  # noqa
 from kuber.versioning import KubernetesVersion  # noqa
 
 #: kuber library version.
-__version__ = '1.11.1'
+__version__ = "1.13.0"
 
 #: The loader used when loading yaml via pyyaml. This can be overridden
 #: in cases where a different Loader is preferred.
@@ -27,15 +30,11 @@ yaml_loader = _yaml.Loader
 
 #: All currently supported versions that exist within this installation
 #: of the kuber library.
-available_versions: _typing.List[KubernetesVersion] = (
-    _versioning.get_all_versions()
-)
+available_versions: _typing.List[KubernetesVersion] = _versioning.get_all_versions()
 
 #: The most recent kubernetes version available within the library, which
 #: can be used to avoid hard-coded versions when creating resource bundles.
-latest_kube_version: KubernetesVersion = (
-    _versioning.get_latest_version(stable=True)
-)
+latest_kube_version: KubernetesVersion = _versioning.get_latest_version(stable=True)
 
 #: Type that accepts either a `KubernetesVersion` object or a string
 #: representation of that version, e.g. 'v1.14' or 'latest'.
@@ -43,8 +42,7 @@ VersionLabel = _typing.Union[KubernetesVersion, str]
 
 
 def create_bundle(
-        kubernetes_version: VersionLabel = None,
-        bundle_name: str = None
+    kubernetes_version: VersionLabel = None, bundle_name: str = None
 ) -> ResourceBundle:
     """
     Creates a `ResourceBundle` instance initialized to define resources from
@@ -65,10 +63,10 @@ def create_bundle(
 
 
 def from_directory_files(
-        directory: str,
-        filenames: _typing.Iterable = None,
-        kubernetes_version: VersionLabel = None,
-        bundle_name: str = None
+    directory: str,
+    filenames: _typing.Iterable[str] = None,
+    kubernetes_version: VersionLabel = None,
+    bundle_name: str = None,
 ) -> ResourceBundle:
     """
     Creates a `ResourceBundle` object from all of the resource
@@ -98,10 +96,10 @@ def from_directory_files(
 
 
 def from_directory(
-        directory: str,
-        recursive: bool = False,
-        kubernetes_version: VersionLabel = None,
-        bundle_name: str = None
+    directory: "PathLike",
+    recursive: bool = False,
+    kubernetes_version: VersionLabel = None,
+    bundle_name: str = None,
 ) -> ResourceBundle:
     """
     Creates a `ResourceBundle` object from all of the yaml and json
@@ -126,13 +124,11 @@ def from_directory(
         Resource objects loaded from the specified directory.
     """
     bundle = ResourceBundle(bundle_name, kubernetes_version)
-    return bundle.add_directory(directory, recursive=recursive)
+    return bundle.add_directory(str(directory), recursive=recursive)
 
 
 def from_file(
-        path: str,
-        kubernetes_version: VersionLabel = None,
-        bundle_name: str = None
+    path: "PathLike", kubernetes_version: VersionLabel = None, bundle_name: str = None
 ) -> ResourceBundle:
     """
     Creates a `ResourceBundle` object and populates it with the Kubernetes
@@ -154,15 +150,95 @@ def from_file(
         specified by the configuration file of the given `path`.
     """
     bundle = ResourceBundle(bundle_name, kubernetes_version)
-    return bundle.add_file(path)
+    return bundle.add_file(str(path))
+
+
+def from_url(
+    url: str, kubernetes_version: VersionLabel = None, bundle_name: str = None
+) -> ResourceBundle:
+    """
+    Creates a `ResourceBundle` object and populates it with the Kubernetes
+    Resource configuration downloaded as a yaml file from the specified remote
+    URL.
+
+    :param url:
+        A URL to a remote YAML file that will be loaded into the bundle.
+    :param kubernetes_version:
+        Kubernetes version in the form MAJOR.MINOR (no patch) that should be
+        used by the bundle when creating and operating on Kubernetes Resource
+        objects (e.g. `Deployment`, `Pod`, etc.). If not specified the most
+        recent version will be used.
+    :param bundle_name:
+        A name to associated with the resource bundle. If not specified, a
+        randomized name will be generated instead.
+    :return:
+        Initialized `ResourceBundle` populated with the Kubernetes Resource
+        specified by the configuration from the remote URL YAML definition.
+    """
+    bundle = ResourceBundle(bundle_name, kubernetes_version)
+    return bundle.add_from_url(url)
+
+
+def from_helm(
+    chart_name: str,
+    values_path: _typing.Union[
+        None,
+        "OptionalPathLike",
+        _typing.Iterable["OptionalPathLike"],
+    ] = None,
+    repos: _typing.Dict[str, str] = None,
+    update: bool = True,
+    kubernetes_version: VersionLabel = None,
+    bundle_name: str = None,
+    namespace: str = None,
+) -> ResourceBundle:
+    """
+    Creates a `ResourceBundle` object and populates it with the Kubernetes
+    Resource configuration rendered from a helm chart.
+
+    :param chart_name:
+        Name of the chart to load and return as a ResourceBundle.
+    :param values_path:
+        An optional path to a values.yaml file (or an iterable of paths to
+        values.yaml files) that will be used to configure the helm chart as
+        it is rendered into the bundle.
+    :param repos:
+        An optional dictionary mapping of helm repositories to add in order
+        to be able to render the specified chart.
+    :param update:
+        Whether or not to have helm update the chart prior to rendering.
+    :param kubernetes_version:
+        Kubernetes version in the form MAJOR.MINOR (no patch) that should be
+        used by the bundle when creating and operating on Kubernetes Resource
+        objects (e.g. `Deployment`, `Pod`, etc.). If not specified the most
+        recent version will be used.
+    :param bundle_name:
+        A name to associated with the resource bundle. If not specified, a
+        randomized name will be generated instead.
+    :param namespace:
+         An optional namespace for the bundle and to apply to the helm chart
+         during its rendering process.
+    :return:
+        Initialized `ResourceBundle` populated with the Kubernetes Resource
+        specified by the configuration from the rendered helm chart.
+    """
+    bundle = ResourceBundle(bundle_name or chart_name, kubernetes_version)
+    bundle.namespace = namespace
+    return bundle.add_from_helm(
+        chart_name=chart_name,
+        values_path=values_path,
+        repos=repos,
+        update=update,
+        namespace=namespace,
+    )
 
 
 def cli(
-        callback: _typing.Callable[['CommandAction'], _typing.Any],
-        kubernetes_version: VersionLabel = None,
-        bundle_name: str = None,
-        arguments: _typing.List[str] = None
-) -> 'management.ResourceBundle':
+    callback: _typing.Callable[["CommandAction"], _typing.Any],
+    kubernetes_version: VersionLabel = None,
+    bundle_name: str = None,
+    arguments: _typing.List[str] = None,
+) -> ResourceBundle:
     """
     Creates an empty bundle configured with the optionally specified
     Kubernetes version and bundle name and immediately invokes the command
@@ -189,11 +265,7 @@ def cli(
         will be parsed from the sys.argv values provided on the command line.
     """
     bundle = create_bundle(
-        kubernetes_version=kubernetes_version,
-        bundle_name=bundle_name
-    )
-    bundle.cli.invoke(
-        callback=callback,
-        arguments=arguments
+        kubernetes_version=kubernetes_version, bundle_name=bundle_name
     )
+    bundle.cli.invoke(callback=callback, arguments=arguments)
     return bundle
