@@ -17,251 +17,260 @@ class CertificateSigningRequest(_kuber_definitions.Resource):
     """
 
     def __init__(
-            self,
-            metadata: 'ObjectMeta' = None,
-            spec: 'CertificateSigningRequestSpec' = None,
-            status: 'CertificateSigningRequestStatus' = None,
+        self,
+        metadata: "ObjectMeta" = None,
+        spec: "CertificateSigningRequestSpec" = None,
+        status: "CertificateSigningRequestStatus" = None,
     ):
         """Create CertificateSigningRequest instance."""
         super(CertificateSigningRequest, self).__init__(
-            api_version='certificates/v1beta1',
-            kind='CertificateSigningRequest'
+            api_version="certificates/v1beta1", kind="CertificateSigningRequest"
         )
         self._properties = {
-            'metadata': metadata if metadata is not None else ObjectMeta(),
-            'spec': spec if spec is not None else CertificateSigningRequestSpec(),
-            'status': status if status is not None else CertificateSigningRequestStatus(),
-
+            "metadata": metadata if metadata is not None else ObjectMeta(),
+            "spec": spec if spec is not None else CertificateSigningRequestSpec(),
+            "status": status
+            if status is not None
+            else CertificateSigningRequestStatus(),
         }
         self._types = {
-            'apiVersion': (str, None),
-            'kind': (str, None),
-            'metadata': (ObjectMeta, None),
-            'spec': (CertificateSigningRequestSpec, None),
-            'status': (CertificateSigningRequestStatus, None),
-
+            "apiVersion": (str, None),
+            "kind": (str, None),
+            "metadata": (ObjectMeta, None),
+            "spec": (CertificateSigningRequestSpec, None),
+            "status": (CertificateSigningRequestStatus, None),
         }
 
     @property
-    def metadata(self) -> 'ObjectMeta':
-        """
-
-        """
-        return self._properties.get('metadata')
+    def metadata(self) -> "ObjectMeta":
+        """"""
+        return typing.cast(
+            "ObjectMeta",
+            self._properties.get("metadata"),
+        )
 
     @metadata.setter
-    def metadata(self, value: typing.Union['ObjectMeta', dict]):
-        """
-
-        """
+    def metadata(self, value: typing.Union["ObjectMeta", dict]):
+        """"""
         if isinstance(value, dict):
-            value = ObjectMeta().from_dict(value)
-        self._properties['metadata'] = value
+            value = typing.cast(
+                ObjectMeta,
+                ObjectMeta().from_dict(value),
+            )
+        self._properties["metadata"] = value
 
     @property
-    def spec(self) -> 'CertificateSigningRequestSpec':
+    def spec(self) -> "CertificateSigningRequestSpec":
         """
         The certificate request itself and any additional
         information.
         """
-        return self._properties.get('spec')
+        return typing.cast(
+            "CertificateSigningRequestSpec",
+            self._properties.get("spec"),
+        )
 
     @spec.setter
-    def spec(self, value: typing.Union['CertificateSigningRequestSpec', dict]):
+    def spec(self, value: typing.Union["CertificateSigningRequestSpec", dict]):
         """
         The certificate request itself and any additional
         information.
         """
         if isinstance(value, dict):
-            value = CertificateSigningRequestSpec().from_dict(value)
-        self._properties['spec'] = value
+            value = typing.cast(
+                CertificateSigningRequestSpec,
+                CertificateSigningRequestSpec().from_dict(value),
+            )
+        self._properties["spec"] = value
 
     @property
-    def status(self) -> 'CertificateSigningRequestStatus':
+    def status(self) -> "CertificateSigningRequestStatus":
         """
         Derived information about the request.
         """
-        return self._properties.get('status')
+        return typing.cast(
+            "CertificateSigningRequestStatus",
+            self._properties.get("status"),
+        )
 
     @status.setter
-    def status(self, value: typing.Union['CertificateSigningRequestStatus', dict]):
+    def status(self, value: typing.Union["CertificateSigningRequestStatus", dict]):
         """
         Derived information about the request.
         """
         if isinstance(value, dict):
-            value = CertificateSigningRequestStatus().from_dict(value)
-        self._properties['status'] = value
+            value = typing.cast(
+                CertificateSigningRequestStatus,
+                CertificateSigningRequestStatus().from_dict(value),
+            )
+        self._properties["status"] = value
 
     def create_resource(
-            self,
-            namespace: 'str' = None
-    ) -> 'CertificateSigningRequestStatus':
+        self, namespace: "str" = None
+    ) -> "CertificateSigningRequestStatus":
         """
         Creates the CertificateSigningRequest in the currently
         configured Kubernetes cluster and returns the status information
         returned by the Kubernetes API after the create is complete.
         """
         names = [
-            'create_namespaced_certificate_signing_request',
-            'create_certificate_signing_request'
+            "create_namespaced_certificate_signing_request",
+            "create_certificate_signing_request",
         ]
 
         response = _kube_api.execute(
-            action='create',
+            action="create",
             resource=self,
             names=names,
             namespace=namespace,
             api_client=None,
-            api_args={'body': self.to_dict()}
-        )
-        return (
-            CertificateSigningRequestStatus()
-            .from_dict(_kube_api.to_kuber_dict(response.status))
+            api_args={"body": self.to_dict()},
         )
 
+        output = CertificateSigningRequestStatus()
+        if response is not None:
+            output.from_dict(_kube_api.to_kuber_dict(response.status))
+        return output
+
     def replace_resource(
-            self,
-            namespace: 'str' = None
-    ) -> 'CertificateSigningRequestStatus':
+        self, namespace: "str" = None
+    ) -> "CertificateSigningRequestStatus":
         """
         Replaces the CertificateSigningRequest in the currently
         configured Kubernetes cluster and returns the status information
         returned by the Kubernetes API after the replace is complete.
         """
         names = [
-            'replace_namespaced_certificate_signing_request',
-            'replace_certificate_signing_request'
+            "replace_namespaced_certificate_signing_request",
+            "replace_certificate_signing_request",
         ]
 
         response = _kube_api.execute(
-            action='replace',
+            action="replace",
             resource=self,
             names=names,
             namespace=namespace,
             api_client=None,
-            api_args={'body': self.to_dict(), 'name': self.metadata.name}
-        )
-        return (
-            CertificateSigningRequestStatus()
-            .from_dict(_kube_api.to_kuber_dict(response.status))
+            api_args={"body": self.to_dict(), "name": self.metadata.name},
         )
 
+        output = CertificateSigningRequestStatus()
+        if response is not None:
+            output.from_dict(_kube_api.to_kuber_dict(response.status))
+        return output
+
     def patch_resource(
-            self,
-            namespace: 'str' = None
-    ) -> 'CertificateSigningRequestStatus':
+        self, namespace: "str" = None
+    ) -> "CertificateSigningRequestStatus":
         """
         Patches the CertificateSigningRequest in the currently
         configured Kubernetes cluster and returns the status information
         returned by the Kubernetes API after the replace is complete.
         """
         names = [
-            'patch_namespaced_certificate_signing_request',
-            'patch_certificate_signing_request'
+            "patch_namespaced_certificate_signing_request",
+            "patch_certificate_signing_request",
         ]
 
         response = _kube_api.execute(
-            action='patch',
+            action="patch",
             resource=self,
             names=names,
             namespace=namespace,
             api_client=None,
-            api_args={'body': self.to_dict(), 'name': self.metadata.name}
-        )
-        return (
-            CertificateSigningRequestStatus()
-            .from_dict(_kube_api.to_kuber_dict(response.status))
+            api_args={"body": self.to_dict(), "name": self.metadata.name},
         )
 
+        output = CertificateSigningRequestStatus()
+        if response is not None:
+            output.from_dict(_kube_api.to_kuber_dict(response.status))
+        return output
+
     def get_resource_status(
-            self,
-            namespace: 'str' = None
-    ) -> 'CertificateSigningRequestStatus':
+        self, namespace: "str" = None
+    ) -> "CertificateSigningRequestStatus":
         """
         Returns status information about the given resource within the cluster.
         """
         names = [
-            'read_namespaced_certificate_signing_request',
-            'read_certificate_signing_request'
+            "read_namespaced_certificate_signing_request",
+            "read_certificate_signing_request",
         ]
 
         response = _kube_api.execute(
-            action='read',
+            action="read",
             resource=self,
             names=names,
             namespace=namespace,
             api_client=None,
-            api_args={'name': self.metadata.name}
-        )
-        return (
-            CertificateSigningRequestStatus()
-            .from_dict(_kube_api.to_kuber_dict(response.status))
+            api_args={"name": self.metadata.name},
         )
 
-    def read_resource(
-            self,
-            namespace: str = None
-    ):
+        output = CertificateSigningRequestStatus()
+        if response is not None:
+            output.from_dict(_kube_api.to_kuber_dict(response.status))
+        return output
+
+    def read_resource(self, namespace: str = None):
         """
         Reads the CertificateSigningRequest from the currently configured
         Kubernetes cluster and returns the low-level definition object.
         """
         names = [
-            'read_namespaced_certificate_signing_request',
-            'read_certificate_signing_request'
+            "read_namespaced_certificate_signing_request",
+            "read_certificate_signing_request",
         ]
         return _kube_api.execute(
-            action='read',
+            action="read",
             resource=self,
             names=names,
             namespace=namespace,
             api_client=None,
-            api_args={'name': self.metadata.name}
+            api_args={"name": self.metadata.name},
         )
 
     def delete_resource(
-            self,
-            namespace: str = None,
-            propagation_policy: str = 'Foreground',
-            grace_period_seconds: int = 10
+        self,
+        namespace: str = None,
+        propagation_policy: str = "Foreground",
+        grace_period_seconds: int = 10,
     ):
         """
         Deletes the CertificateSigningRequest from the currently configured
         Kubernetes cluster.
         """
         names = [
-            'delete_namespaced_certificate_signing_request',
-            'delete_certificate_signing_request'
+            "delete_namespaced_certificate_signing_request",
+            "delete_certificate_signing_request",
         ]
 
         body = client.V1DeleteOptions(
             propagation_policy=propagation_policy,
-            grace_period_seconds=grace_period_seconds
+            grace_period_seconds=grace_period_seconds,
         )
 
         _kube_api.execute(
-            action='delete',
+            action="delete",
             resource=self,
             names=names,
             namespace=namespace,
             api_client=None,
-            api_args={'name': self.metadata.name, 'body': body}
+            api_args={"name": self.metadata.name, "body": body},
         )
 
     @staticmethod
     def get_resource_api(
-            api_client: client.ApiClient = None,
-            **kwargs
-    ) -> 'client.CertificatesV1beta1Api':
+        api_client: client.ApiClient = None, **kwargs
+    ) -> "client.CertificatesV1beta1Api":
         """
         Returns an instance of the kubernetes API client associated with
         this object.
         """
         if api_client:
-            kwargs['apl_client'] = api_client
+            kwargs["apl_client"] = api_client
         return client.CertificatesV1beta1Api(**kwargs)
 
-    def __enter__(self) -> 'CertificateSigningRequest':
+    def __enter__(self) -> "CertificateSigningRequest":
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
@@ -269,41 +278,41 @@ class CertificateSigningRequest(_kuber_definitions.Resource):
 
 
 class CertificateSigningRequestCondition(_kuber_definitions.Definition):
-    """
-
-    """
+    """"""
 
     def __init__(
-            self,
-            last_transition_time: str = None,
-            last_update_time: str = None,
-            message: str = None,
-            reason: str = None,
-            status: str = None,
-            type_: str = None,
+        self,
+        last_transition_time: str = None,
+        last_update_time: str = None,
+        message: str = None,
+        reason: str = None,
+        status: str = None,
+        type_: str = None,
     ):
         """Create CertificateSigningRequestCondition instance."""
         super(CertificateSigningRequestCondition, self).__init__(
-            api_version='certificates/v1beta1',
-            kind='CertificateSigningRequestCondition'
+            api_version="certificates/v1beta1",
+            kind="CertificateSigningRequestCondition",
         )
         self._properties = {
-            'lastTransitionTime': last_transition_time if last_transition_time is not None else None,
-            'lastUpdateTime': last_update_time if last_update_time is not None else None,
-            'message': message if message is not None else '',
-            'reason': reason if reason is not None else '',
-            'status': status if status is not None else '',
-            'type': type_ if type_ is not None else '',
-
+            "lastTransitionTime": last_transition_time
+            if last_transition_time is not None
+            else None,
+            "lastUpdateTime": last_update_time
+            if last_update_time is not None
+            else None,
+            "message": message if message is not None else "",
+            "reason": reason if reason is not None else "",
+            "status": status if status is not None else "",
+            "type": type_ if type_ is not None else "",
         }
         self._types = {
-            'lastTransitionTime': (str, None),
-            'lastUpdateTime': (str, None),
-            'message': (str, None),
-            'reason': (str, None),
-            'status': (str, None),
-            'type': (str, None),
-
+            "lastTransitionTime": (str, None),
+            "lastUpdateTime": (str, None),
+            "message": (str, None),
+            "reason": (str, None),
+            "status": (str, None),
+            "type": (str, None),
         }
 
     @property
@@ -315,12 +324,14 @@ class CertificateSigningRequestCondition(_kuber_definitions.Definition):
         status is changed, the server defaults this to the current
         time.
         """
-        return self._properties.get('lastTransitionTime')
+        return typing.cast(
+            str,
+            self._properties.get("lastTransitionTime"),
+        )
 
     @last_transition_time.setter
     def last_transition_time(
-            self,
-            value: typing.Union[str, _datetime.datetime, _datetime.date]
+        self, value: typing.Union[str, _datetime.datetime, _datetime.date]
     ):
         """
         lastTransitionTime is the time the condition last
@@ -330,59 +341,67 @@ class CertificateSigningRequestCondition(_kuber_definitions.Definition):
         time.
         """
         if isinstance(value, _datetime.datetime):
-            value = value.strftime('%Y-%m-%dT%H:%M:%SZ')
+            value = value.strftime("%Y-%m-%dT%H:%M:%SZ")
         elif isinstance(value, _datetime.date):
-            value = value.strftime('%Y-%m-%dT00:00:00Z')
-        self._properties['lastTransitionTime'] = value
+            value = value.strftime("%Y-%m-%dT00:00:00Z")
+        self._properties["lastTransitionTime"] = value
 
     @property
     def last_update_time(self) -> str:
         """
         timestamp for the last update to this condition
         """
-        return self._properties.get('lastUpdateTime')
+        return typing.cast(
+            str,
+            self._properties.get("lastUpdateTime"),
+        )
 
     @last_update_time.setter
     def last_update_time(
-            self,
-            value: typing.Union[str, _datetime.datetime, _datetime.date]
+        self, value: typing.Union[str, _datetime.datetime, _datetime.date]
     ):
         """
         timestamp for the last update to this condition
         """
         if isinstance(value, _datetime.datetime):
-            value = value.strftime('%Y-%m-%dT%H:%M:%SZ')
+            value = value.strftime("%Y-%m-%dT%H:%M:%SZ")
         elif isinstance(value, _datetime.date):
-            value = value.strftime('%Y-%m-%dT00:00:00Z')
-        self._properties['lastUpdateTime'] = value
+            value = value.strftime("%Y-%m-%dT00:00:00Z")
+        self._properties["lastUpdateTime"] = value
 
     @property
     def message(self) -> str:
         """
         human readable message with details about the request state
         """
-        return self._properties.get('message')
+        return typing.cast(
+            str,
+            self._properties.get("message"),
+        )
 
     @message.setter
     def message(self, value: str):
         """
         human readable message with details about the request state
         """
-        self._properties['message'] = value
+        self._properties["message"] = value
 
     @property
     def reason(self) -> str:
         """
         brief reason for the request state
         """
-        return self._properties.get('reason')
+        return typing.cast(
+            str,
+            self._properties.get("reason"),
+        )
 
     @reason.setter
     def reason(self, value: str):
         """
         brief reason for the request state
         """
-        self._properties['reason'] = value
+        self._properties["reason"] = value
 
     @property
     def status(self) -> str:
@@ -392,7 +411,10 @@ class CertificateSigningRequestCondition(_kuber_definitions.Definition):
         or "Unknown". Defaults to "True". If unset, should be
         treated as "True".
         """
-        return self._properties.get('status')
+        return typing.cast(
+            str,
+            self._properties.get("status"),
+        )
 
     @status.setter
     def status(self, value: str):
@@ -402,7 +424,7 @@ class CertificateSigningRequestCondition(_kuber_definitions.Definition):
         or "Unknown". Defaults to "True". If unset, should be
         treated as "True".
         """
-        self._properties['status'] = value
+        self._properties["status"] = value
 
     @property
     def type_(self) -> str:
@@ -410,7 +432,10 @@ class CertificateSigningRequestCondition(_kuber_definitions.Definition):
         type of the condition. Known conditions include "Approved",
         "Denied", and "Failed".
         """
-        return self._properties.get('type')
+        return typing.cast(
+            str,
+            self._properties.get("type"),
+        )
 
     @type_.setter
     def type_(self, value: str):
@@ -418,9 +443,9 @@ class CertificateSigningRequestCondition(_kuber_definitions.Definition):
         type of the condition. Known conditions include "Approved",
         "Denied", and "Failed".
         """
-        self._properties['type'] = value
+        self._properties["type"] = value
 
-    def __enter__(self) -> 'CertificateSigningRequestCondition':
+    def __enter__(self) -> "CertificateSigningRequestCondition":
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
@@ -428,85 +453,85 @@ class CertificateSigningRequestCondition(_kuber_definitions.Definition):
 
 
 class CertificateSigningRequestList(_kuber_definitions.Collection):
-    """
-
-    """
+    """"""
 
     def __init__(
-            self,
-            items: typing.List['CertificateSigningRequest'] = None,
-            metadata: 'ListMeta' = None,
+        self,
+        items: typing.List["CertificateSigningRequest"] = None,
+        metadata: "ListMeta" = None,
     ):
         """Create CertificateSigningRequestList instance."""
         super(CertificateSigningRequestList, self).__init__(
-            api_version='certificates/v1beta1',
-            kind='CertificateSigningRequestList'
+            api_version="certificates/v1beta1", kind="CertificateSigningRequestList"
         )
         self._properties = {
-            'items': items if items is not None else [],
-            'metadata': metadata if metadata is not None else ListMeta(),
-
+            "items": items if items is not None else [],
+            "metadata": metadata if metadata is not None else ListMeta(),
         }
         self._types = {
-            'apiVersion': (str, None),
-            'items': (list, CertificateSigningRequest),
-            'kind': (str, None),
-            'metadata': (ListMeta, None),
-
+            "apiVersion": (str, None),
+            "items": (list, CertificateSigningRequest),
+            "kind": (str, None),
+            "metadata": (ListMeta, None),
         }
 
     @property
-    def items(self) -> typing.List['CertificateSigningRequest']:
-        """
-
-        """
-        return self._properties.get('items')
+    def items(self) -> typing.List["CertificateSigningRequest"]:
+        """"""
+        return typing.cast(
+            typing.List["CertificateSigningRequest"],
+            self._properties.get("items"),
+        )
 
     @items.setter
     def items(
-            self,
-            value: typing.Union[typing.List['CertificateSigningRequest'], typing.List[dict]]
+        self,
+        value: typing.Union[
+            typing.List["CertificateSigningRequest"], typing.List[dict]
+        ],
     ):
-        """
-
-        """
-        cleaned = []
+        """"""
+        cleaned: typing.List[CertificateSigningRequest] = []
         for item in value:
             if isinstance(item, dict):
-                item = CertificateSigningRequest().from_dict(item)
-            cleaned.append(item)
-        self._properties['items'] = cleaned
+                item = typing.cast(
+                    CertificateSigningRequest,
+                    CertificateSigningRequest().from_dict(item),
+                )
+            cleaned.append(typing.cast(CertificateSigningRequest, item))
+        self._properties["items"] = cleaned
 
     @property
-    def metadata(self) -> 'ListMeta':
-        """
-
-        """
-        return self._properties.get('metadata')
+    def metadata(self) -> "ListMeta":
+        """"""
+        return typing.cast(
+            "ListMeta",
+            self._properties.get("metadata"),
+        )
 
     @metadata.setter
-    def metadata(self, value: typing.Union['ListMeta', dict]):
-        """
-
-        """
+    def metadata(self, value: typing.Union["ListMeta", dict]):
+        """"""
         if isinstance(value, dict):
-            value = ListMeta().from_dict(value)
-        self._properties['metadata'] = value
+            value = typing.cast(
+                ListMeta,
+                ListMeta().from_dict(value),
+            )
+        self._properties["metadata"] = value
 
     @staticmethod
     def get_resource_api(
-            api_client: client.ApiClient = None,
-            **kwargs
-    ) -> 'client.CertificatesV1beta1Api':
+        api_client: client.ApiClient = None, **kwargs
+    ) -> "client.CertificatesV1beta1Api":
         """
         Returns an instance of the kubernetes API client associated with
         this object.
         """
         if api_client:
-            kwargs['apl_client'] = api_client
+            kwargs["apl_client"] = api_client
         return client.CertificatesV1beta1Api(**kwargs)
 
-    def __enter__(self) -> 'CertificateSigningRequestList':
+    def __enter__(self) -> "CertificateSigningRequestList":
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
@@ -522,39 +547,36 @@ class CertificateSigningRequestSpec(_kuber_definitions.Definition):
     """
 
     def __init__(
-            self,
-            extra: dict = None,
-            groups: typing.List[str] = None,
-            request: str = None,
-            signer_name: str = None,
-            uid: str = None,
-            usages: typing.List[str] = None,
-            username: str = None,
+        self,
+        extra: dict = None,
+        groups: typing.List[str] = None,
+        request: str = None,
+        signer_name: str = None,
+        uid: str = None,
+        usages: typing.List[str] = None,
+        username: str = None,
     ):
         """Create CertificateSigningRequestSpec instance."""
         super(CertificateSigningRequestSpec, self).__init__(
-            api_version='certificates/v1beta1',
-            kind='CertificateSigningRequestSpec'
+            api_version="certificates/v1beta1", kind="CertificateSigningRequestSpec"
         )
         self._properties = {
-            'extra': extra if extra is not None else {},
-            'groups': groups if groups is not None else [],
-            'request': request if request is not None else '',
-            'signerName': signer_name if signer_name is not None else '',
-            'uid': uid if uid is not None else '',
-            'usages': usages if usages is not None else [],
-            'username': username if username is not None else '',
-
+            "extra": extra if extra is not None else {},
+            "groups": groups if groups is not None else [],
+            "request": request if request is not None else "",
+            "signerName": signer_name if signer_name is not None else "",
+            "uid": uid if uid is not None else "",
+            "usages": usages if usages is not None else [],
+            "username": username if username is not None else "",
         }
         self._types = {
-            'extra': (dict, None),
-            'groups': (list, str),
-            'request': (str, None),
-            'signerName': (str, None),
-            'uid': (str, None),
-            'usages': (list, str),
-            'username': (str, None),
-
+            "extra": (dict, None),
+            "groups": (list, str),
+            "request": (str, None),
+            "signerName": (str, None),
+            "uid": (str, None),
+            "usages": (list, str),
+            "username": (str, None),
         }
 
     @property
@@ -563,7 +585,10 @@ class CertificateSigningRequestSpec(_kuber_definitions.Definition):
         Extra information about the requesting user. See user.Info
         interface for details.
         """
-        return self._properties.get('extra')
+        return typing.cast(
+            dict,
+            self._properties.get("extra"),
+        )
 
     @extra.setter
     def extra(self, value: dict):
@@ -571,7 +596,7 @@ class CertificateSigningRequestSpec(_kuber_definitions.Definition):
         Extra information about the requesting user. See user.Info
         interface for details.
         """
-        self._properties['extra'] = value
+        self._properties["extra"] = value
 
     @property
     def groups(self) -> typing.List[str]:
@@ -579,7 +604,10 @@ class CertificateSigningRequestSpec(_kuber_definitions.Definition):
         Group information about the requesting user. See user.Info
         interface for details.
         """
-        return self._properties.get('groups')
+        return typing.cast(
+            typing.List[str],
+            self._properties.get("groups"),
+        )
 
     @groups.setter
     def groups(self, value: typing.List[str]):
@@ -587,21 +615,24 @@ class CertificateSigningRequestSpec(_kuber_definitions.Definition):
         Group information about the requesting user. See user.Info
         interface for details.
         """
-        self._properties['groups'] = value
+        self._properties["groups"] = value
 
     @property
     def request(self) -> str:
         """
         Base64-encoded PKCS#10 CSR data
         """
-        return self._properties.get('request')
+        return typing.cast(
+            str,
+            self._properties.get("request"),
+        )
 
     @request.setter
     def request(self, value: str):
         """
         Base64-encoded PKCS#10 CSR data
         """
-        self._properties['request'] = value
+        self._properties["request"] = value
 
     @property
     def signer_name(self) -> str:
@@ -618,7 +649,10 @@ class CertificateSigningRequestSpec(_kuber_definitions.Definition):
         Distribution of trust for signers happens out of band. You
         can select on this field using `spec.signerName`.
         """
-        return self._properties.get('signerName')
+        return typing.cast(
+            str,
+            self._properties.get("signerName"),
+        )
 
     @signer_name.setter
     def signer_name(self, value: str):
@@ -635,7 +669,7 @@ class CertificateSigningRequestSpec(_kuber_definitions.Definition):
         Distribution of trust for signers happens out of band. You
         can select on this field using `spec.signerName`.
         """
-        self._properties['signerName'] = value
+        self._properties["signerName"] = value
 
     @property
     def uid(self) -> str:
@@ -643,7 +677,10 @@ class CertificateSigningRequestSpec(_kuber_definitions.Definition):
         UID information about the requesting user. See user.Info
         interface for details.
         """
-        return self._properties.get('uid')
+        return typing.cast(
+            str,
+            self._properties.get("uid"),
+        )
 
     @uid.setter
     def uid(self, value: str):
@@ -651,7 +688,7 @@ class CertificateSigningRequestSpec(_kuber_definitions.Definition):
         UID information about the requesting user. See user.Info
         interface for details.
         """
-        self._properties['uid'] = value
+        self._properties["uid"] = value
 
     @property
     def usages(self) -> typing.List[str]:
@@ -685,7 +722,10 @@ class CertificateSigningRequestSpec(_kuber_definitions.Definition):
          "microsoft sgc",
          "netscape sgc"
         """
-        return self._properties.get('usages')
+        return typing.cast(
+            typing.List[str],
+            self._properties.get("usages"),
+        )
 
     @usages.setter
     def usages(self, value: typing.List[str]):
@@ -719,7 +759,7 @@ class CertificateSigningRequestSpec(_kuber_definitions.Definition):
          "microsoft sgc",
          "netscape sgc"
         """
-        self._properties['usages'] = value
+        self._properties["usages"] = value
 
     @property
     def username(self) -> str:
@@ -727,7 +767,10 @@ class CertificateSigningRequestSpec(_kuber_definitions.Definition):
         Information about the requesting user. See user.Info
         interface for details.
         """
-        return self._properties.get('username')
+        return typing.cast(
+            str,
+            self._properties.get("username"),
+        )
 
     @username.setter
     def username(self, value: str):
@@ -735,9 +778,9 @@ class CertificateSigningRequestSpec(_kuber_definitions.Definition):
         Information about the requesting user. See user.Info
         interface for details.
         """
-        self._properties['username'] = value
+        self._properties["username"] = value
 
-    def __enter__(self) -> 'CertificateSigningRequestSpec':
+    def __enter__(self) -> "CertificateSigningRequestSpec":
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
@@ -745,29 +788,24 @@ class CertificateSigningRequestSpec(_kuber_definitions.Definition):
 
 
 class CertificateSigningRequestStatus(_kuber_definitions.Definition):
-    """
-
-    """
+    """"""
 
     def __init__(
-            self,
-            certificate: str = None,
-            conditions: typing.List['CertificateSigningRequestCondition'] = None,
+        self,
+        certificate: str = None,
+        conditions: typing.List["CertificateSigningRequestCondition"] = None,
     ):
         """Create CertificateSigningRequestStatus instance."""
         super(CertificateSigningRequestStatus, self).__init__(
-            api_version='certificates/v1beta1',
-            kind='CertificateSigningRequestStatus'
+            api_version="certificates/v1beta1", kind="CertificateSigningRequestStatus"
         )
         self._properties = {
-            'certificate': certificate if certificate is not None else '',
-            'conditions': conditions if conditions is not None else [],
-
+            "certificate": certificate if certificate is not None else "",
+            "conditions": conditions if conditions is not None else [],
         }
         self._types = {
-            'certificate': (str, None),
-            'conditions': (list, CertificateSigningRequestCondition),
-
+            "certificate": (str, None),
+            "conditions": (list, CertificateSigningRequestCondition),
         }
 
     @property
@@ -776,7 +814,10 @@ class CertificateSigningRequestStatus(_kuber_definitions.Definition):
         If request was approved, the controller will place the
         issued certificate here.
         """
-        return self._properties.get('certificate')
+        return typing.cast(
+            str,
+            self._properties.get("certificate"),
+        )
 
     @certificate.setter
     def certificate(self, value: str):
@@ -784,33 +825,41 @@ class CertificateSigningRequestStatus(_kuber_definitions.Definition):
         If request was approved, the controller will place the
         issued certificate here.
         """
-        self._properties['certificate'] = value
+        self._properties["certificate"] = value
 
     @property
-    def conditions(self) -> typing.List['CertificateSigningRequestCondition']:
+    def conditions(self) -> typing.List["CertificateSigningRequestCondition"]:
         """
         Conditions applied to the request, such as approval or
         denial.
         """
-        return self._properties.get('conditions')
+        return typing.cast(
+            typing.List["CertificateSigningRequestCondition"],
+            self._properties.get("conditions"),
+        )
 
     @conditions.setter
     def conditions(
-            self,
-            value: typing.Union[typing.List['CertificateSigningRequestCondition'], typing.List[dict]]
+        self,
+        value: typing.Union[
+            typing.List["CertificateSigningRequestCondition"], typing.List[dict]
+        ],
     ):
         """
         Conditions applied to the request, such as approval or
         denial.
         """
-        cleaned = []
+        cleaned: typing.List[CertificateSigningRequestCondition] = []
         for item in value:
             if isinstance(item, dict):
-                item = CertificateSigningRequestCondition().from_dict(item)
-            cleaned.append(item)
-        self._properties['conditions'] = cleaned
+                item = typing.cast(
+                    CertificateSigningRequestCondition,
+                    CertificateSigningRequestCondition().from_dict(item),
+                )
+            cleaned.append(typing.cast(CertificateSigningRequestCondition, item))
+        self._properties["conditions"] = cleaned
 
-    def __enter__(self) -> 'CertificateSigningRequestStatus':
+    def __enter__(self) -> "CertificateSigningRequestStatus":
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
