@@ -19,43 +19,46 @@ class HTTPIngressPath(_kuber_definitions.Definition):
     """
 
     def __init__(
-            self,
-            backend: 'IngressBackend' = None,
-            path: str = None,
+        self,
+        backend: "IngressBackend" = None,
+        path: str = None,
     ):
         """Create HTTPIngressPath instance."""
         super(HTTPIngressPath, self).__init__(
-            api_version='networking/v1beta1',
-            kind='HTTPIngressPath'
+            api_version="networking/v1beta1", kind="HTTPIngressPath"
         )
         self._properties = {
-            'backend': backend if backend is not None else IngressBackend(),
-            'path': path if path is not None else '',
-
+            "backend": backend if backend is not None else IngressBackend(),
+            "path": path if path is not None else "",
         }
         self._types = {
-            'backend': (IngressBackend, None),
-            'path': (str, None),
-
+            "backend": (IngressBackend, None),
+            "path": (str, None),
         }
 
     @property
-    def backend(self) -> 'IngressBackend':
+    def backend(self) -> "IngressBackend":
         """
         Backend defines the referenced service endpoint to which the
         traffic will be forwarded to.
         """
-        return self._properties.get('backend')
+        return typing.cast(
+            "IngressBackend",
+            self._properties.get("backend"),
+        )
 
     @backend.setter
-    def backend(self, value: typing.Union['IngressBackend', dict]):
+    def backend(self, value: typing.Union["IngressBackend", dict]):
         """
         Backend defines the referenced service endpoint to which the
         traffic will be forwarded to.
         """
         if isinstance(value, dict):
-            value = IngressBackend().from_dict(value)
-        self._properties['backend'] = value
+            value = typing.cast(
+                IngressBackend,
+                IngressBackend().from_dict(value),
+            )
+        self._properties["backend"] = value
 
     @property
     def path(self) -> str:
@@ -68,7 +71,10 @@ class HTTPIngressPath(_kuber_definitions.Definition):
         3986. Paths must begin with a '/'. If unspecified, the path
         defaults to a catch all sending traffic to the backend.
         """
-        return self._properties.get('path')
+        return typing.cast(
+            str,
+            self._properties.get("path"),
+        )
 
     @path.setter
     def path(self, value: str):
@@ -81,9 +87,9 @@ class HTTPIngressPath(_kuber_definitions.Definition):
         3986. Paths must begin with a '/'. If unspecified, the path
         defaults to a catch all sending traffic to the backend.
         """
-        self._properties['path'] = value
+        self._properties["path"] = value
 
-    def __enter__(self) -> 'HTTPIngressPath':
+    def __enter__(self) -> "HTTPIngressPath":
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
@@ -100,46 +106,48 @@ class HTTPIngressRuleValue(_kuber_definitions.Definition):
     """
 
     def __init__(
-            self,
-            paths: typing.List['HTTPIngressPath'] = None,
+        self,
+        paths: typing.List["HTTPIngressPath"] = None,
     ):
         """Create HTTPIngressRuleValue instance."""
         super(HTTPIngressRuleValue, self).__init__(
-            api_version='networking/v1beta1',
-            kind='HTTPIngressRuleValue'
+            api_version="networking/v1beta1", kind="HTTPIngressRuleValue"
         )
         self._properties = {
-            'paths': paths if paths is not None else [],
-
+            "paths": paths if paths is not None else [],
         }
         self._types = {
-            'paths': (list, HTTPIngressPath),
-
+            "paths": (list, HTTPIngressPath),
         }
 
     @property
-    def paths(self) -> typing.List['HTTPIngressPath']:
+    def paths(self) -> typing.List["HTTPIngressPath"]:
         """
         A collection of paths that map requests to backends.
         """
-        return self._properties.get('paths')
+        return typing.cast(
+            typing.List["HTTPIngressPath"],
+            self._properties.get("paths"),
+        )
 
     @paths.setter
     def paths(
-            self,
-            value: typing.Union[typing.List['HTTPIngressPath'], typing.List[dict]]
+        self, value: typing.Union[typing.List["HTTPIngressPath"], typing.List[dict]]
     ):
         """
         A collection of paths that map requests to backends.
         """
-        cleaned = []
+        cleaned: typing.List[HTTPIngressPath] = []
         for item in value:
             if isinstance(item, dict):
-                item = HTTPIngressPath().from_dict(item)
-            cleaned.append(item)
-        self._properties['paths'] = cleaned
+                item = typing.cast(
+                    HTTPIngressPath,
+                    HTTPIngressPath().from_dict(item),
+                )
+            cleaned.append(typing.cast(HTTPIngressPath, item))
+        self._properties["paths"] = cleaned
 
-    def __enter__(self) -> 'HTTPIngressRuleValue':
+    def __enter__(self) -> "HTTPIngressRuleValue":
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
@@ -156,261 +164,250 @@ class Ingress(_kuber_definitions.Resource):
     """
 
     def __init__(
-            self,
-            metadata: 'ObjectMeta' = None,
-            spec: 'IngressSpec' = None,
-            status: 'IngressStatus' = None,
+        self,
+        metadata: "ObjectMeta" = None,
+        spec: "IngressSpec" = None,
+        status: "IngressStatus" = None,
     ):
         """Create Ingress instance."""
-        super(Ingress, self).__init__(
-            api_version='networking/v1beta1',
-            kind='Ingress'
-        )
+        super(Ingress, self).__init__(api_version="networking/v1beta1", kind="Ingress")
         self._properties = {
-            'metadata': metadata if metadata is not None else ObjectMeta(),
-            'spec': spec if spec is not None else IngressSpec(),
-            'status': status if status is not None else IngressStatus(),
-
+            "metadata": metadata if metadata is not None else ObjectMeta(),
+            "spec": spec if spec is not None else IngressSpec(),
+            "status": status if status is not None else IngressStatus(),
         }
         self._types = {
-            'apiVersion': (str, None),
-            'kind': (str, None),
-            'metadata': (ObjectMeta, None),
-            'spec': (IngressSpec, None),
-            'status': (IngressStatus, None),
-
+            "apiVersion": (str, None),
+            "kind": (str, None),
+            "metadata": (ObjectMeta, None),
+            "spec": (IngressSpec, None),
+            "status": (IngressStatus, None),
         }
 
     @property
-    def metadata(self) -> 'ObjectMeta':
+    def metadata(self) -> "ObjectMeta":
         """
         Standard object's metadata. More info:
         https://git.k8s.io/community/contributors/devel/api-
         conventions.md#metadata
         """
-        return self._properties.get('metadata')
+        return typing.cast(
+            "ObjectMeta",
+            self._properties.get("metadata"),
+        )
 
     @metadata.setter
-    def metadata(self, value: typing.Union['ObjectMeta', dict]):
+    def metadata(self, value: typing.Union["ObjectMeta", dict]):
         """
         Standard object's metadata. More info:
         https://git.k8s.io/community/contributors/devel/api-
         conventions.md#metadata
         """
         if isinstance(value, dict):
-            value = ObjectMeta().from_dict(value)
-        self._properties['metadata'] = value
+            value = typing.cast(
+                ObjectMeta,
+                ObjectMeta().from_dict(value),
+            )
+        self._properties["metadata"] = value
 
     @property
-    def spec(self) -> 'IngressSpec':
+    def spec(self) -> "IngressSpec":
         """
         Spec is the desired state of the Ingress. More info:
         https://git.k8s.io/community/contributors/devel/api-
         conventions.md#spec-and-status
         """
-        return self._properties.get('spec')
+        return typing.cast(
+            "IngressSpec",
+            self._properties.get("spec"),
+        )
 
     @spec.setter
-    def spec(self, value: typing.Union['IngressSpec', dict]):
+    def spec(self, value: typing.Union["IngressSpec", dict]):
         """
         Spec is the desired state of the Ingress. More info:
         https://git.k8s.io/community/contributors/devel/api-
         conventions.md#spec-and-status
         """
         if isinstance(value, dict):
-            value = IngressSpec().from_dict(value)
-        self._properties['spec'] = value
+            value = typing.cast(
+                IngressSpec,
+                IngressSpec().from_dict(value),
+            )
+        self._properties["spec"] = value
 
     @property
-    def status(self) -> 'IngressStatus':
+    def status(self) -> "IngressStatus":
         """
         Status is the current state of the Ingress. More info:
         https://git.k8s.io/community/contributors/devel/api-
         conventions.md#spec-and-status
         """
-        return self._properties.get('status')
+        return typing.cast(
+            "IngressStatus",
+            self._properties.get("status"),
+        )
 
     @status.setter
-    def status(self, value: typing.Union['IngressStatus', dict]):
+    def status(self, value: typing.Union["IngressStatus", dict]):
         """
         Status is the current state of the Ingress. More info:
         https://git.k8s.io/community/contributors/devel/api-
         conventions.md#spec-and-status
         """
         if isinstance(value, dict):
-            value = IngressStatus().from_dict(value)
-        self._properties['status'] = value
+            value = typing.cast(
+                IngressStatus,
+                IngressStatus().from_dict(value),
+            )
+        self._properties["status"] = value
 
-    def create_resource(
-            self,
-            namespace: 'str' = None
-    ) -> 'IngressStatus':
+    def create_resource(self, namespace: "str" = None) -> "IngressStatus":
         """
         Creates the Ingress in the currently
         configured Kubernetes cluster and returns the status information
         returned by the Kubernetes API after the create is complete.
         """
-        names = [
-            'create_namespaced_ingress',
-            'create_ingress'
-        ]
+        names = ["create_namespaced_ingress", "create_ingress"]
 
         response = _kube_api.execute(
-            action='create',
+            action="create",
             resource=self,
             names=names,
             namespace=namespace,
             api_client=None,
-            api_args={'body': self.to_dict()}
-        )
-        return (
-            IngressStatus()
-            .from_dict(_kube_api.to_kuber_dict(response.status))
+            api_args={"body": self.to_dict()},
         )
 
-    def replace_resource(
-            self,
-            namespace: 'str' = None
-    ) -> 'IngressStatus':
+        output = IngressStatus()
+        if response is not None:
+            output.from_dict(_kube_api.to_kuber_dict(response.status))
+        return output
+
+    def replace_resource(self, namespace: "str" = None) -> "IngressStatus":
         """
         Replaces the Ingress in the currently
         configured Kubernetes cluster and returns the status information
         returned by the Kubernetes API after the replace is complete.
         """
-        names = [
-            'replace_namespaced_ingress',
-            'replace_ingress'
-        ]
+        names = ["replace_namespaced_ingress", "replace_ingress"]
 
         response = _kube_api.execute(
-            action='replace',
+            action="replace",
             resource=self,
             names=names,
             namespace=namespace,
             api_client=None,
-            api_args={'body': self.to_dict(), 'name': self.metadata.name}
-        )
-        return (
-            IngressStatus()
-            .from_dict(_kube_api.to_kuber_dict(response.status))
+            api_args={"body": self.to_dict(), "name": self.metadata.name},
         )
 
-    def patch_resource(
-            self,
-            namespace: 'str' = None
-    ) -> 'IngressStatus':
+        output = IngressStatus()
+        if response is not None:
+            output.from_dict(_kube_api.to_kuber_dict(response.status))
+        return output
+
+    def patch_resource(self, namespace: "str" = None) -> "IngressStatus":
         """
         Patches the Ingress in the currently
         configured Kubernetes cluster and returns the status information
         returned by the Kubernetes API after the replace is complete.
         """
-        names = [
-            'patch_namespaced_ingress',
-            'patch_ingress'
-        ]
+        names = ["patch_namespaced_ingress", "patch_ingress"]
 
         response = _kube_api.execute(
-            action='patch',
+            action="patch",
             resource=self,
             names=names,
             namespace=namespace,
             api_client=None,
-            api_args={'body': self.to_dict(), 'name': self.metadata.name}
-        )
-        return (
-            IngressStatus()
-            .from_dict(_kube_api.to_kuber_dict(response.status))
+            api_args={"body": self.to_dict(), "name": self.metadata.name},
         )
 
-    def get_resource_status(
-            self,
-            namespace: 'str' = None
-    ) -> 'IngressStatus':
+        output = IngressStatus()
+        if response is not None:
+            output.from_dict(_kube_api.to_kuber_dict(response.status))
+        return output
+
+    def get_resource_status(self, namespace: "str" = None) -> "IngressStatus":
         """
         Returns status information about the given resource within the cluster.
         """
-        names = [
-            'read_namespaced_ingress',
-            'read_ingress'
-        ]
+        names = ["read_namespaced_ingress", "read_ingress"]
 
         response = _kube_api.execute(
-            action='read',
+            action="read",
             resource=self,
             names=names,
             namespace=namespace,
             api_client=None,
-            api_args={'name': self.metadata.name}
-        )
-        return (
-            IngressStatus()
-            .from_dict(_kube_api.to_kuber_dict(response.status))
+            api_args={"name": self.metadata.name},
         )
 
-    def read_resource(
-            self,
-            namespace: str = None
-    ):
+        output = IngressStatus()
+        if response is not None:
+            output.from_dict(_kube_api.to_kuber_dict(response.status))
+        return output
+
+    def read_resource(self, namespace: str = None):
         """
         Reads the Ingress from the currently configured
         Kubernetes cluster and returns the low-level definition object.
         """
         names = [
-            'read_namespaced_ingress',
-            'read_ingress'
+            "read_namespaced_ingress",
+            "read_ingress",
         ]
         return _kube_api.execute(
-            action='read',
+            action="read",
             resource=self,
             names=names,
             namespace=namespace,
             api_client=None,
-            api_args={'name': self.metadata.name}
+            api_args={"name": self.metadata.name},
         )
 
     def delete_resource(
-            self,
-            namespace: str = None,
-            propagation_policy: str = 'Foreground',
-            grace_period_seconds: int = 10
+        self,
+        namespace: str = None,
+        propagation_policy: str = "Foreground",
+        grace_period_seconds: int = 10,
     ):
         """
         Deletes the Ingress from the currently configured
         Kubernetes cluster.
         """
         names = [
-            'delete_namespaced_ingress',
-            'delete_ingress'
+            "delete_namespaced_ingress",
+            "delete_ingress",
         ]
 
         body = client.V1DeleteOptions(
             propagation_policy=propagation_policy,
-            grace_period_seconds=grace_period_seconds
+            grace_period_seconds=grace_period_seconds,
         )
 
         _kube_api.execute(
-            action='delete',
+            action="delete",
             resource=self,
             names=names,
             namespace=namespace,
             api_client=None,
-            api_args={'name': self.metadata.name, 'body': body}
+            api_args={"name": self.metadata.name, "body": body},
         )
 
     @staticmethod
     def get_resource_api(
-            api_client: client.ApiClient = None,
-            **kwargs
-    ) -> 'client.NetworkingV1beta1Api':
+        api_client: client.ApiClient = None, **kwargs
+    ) -> "client.NetworkingV1beta1Api":
         """
         Returns an instance of the kubernetes API client associated with
         this object.
         """
         if api_client:
-            kwargs['apl_client'] = api_client
+            kwargs["apl_client"] = api_client
         return client.NetworkingV1beta1Api(**kwargs)
 
-    def __enter__(self) -> 'Ingress':
+    def __enter__(self) -> "Ingress":
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
@@ -424,24 +421,21 @@ class IngressBackend(_kuber_definitions.Definition):
     """
 
     def __init__(
-            self,
-            service_name: str = None,
-            service_port: typing.Union[str, int, None] = None,
+        self,
+        service_name: str = None,
+        service_port: typing.Union[str, int, None] = None,
     ):
         """Create IngressBackend instance."""
         super(IngressBackend, self).__init__(
-            api_version='networking/v1beta1',
-            kind='IngressBackend'
+            api_version="networking/v1beta1", kind="IngressBackend"
         )
         self._properties = {
-            'serviceName': service_name if service_name is not None else '',
-            'servicePort': service_port if service_port is not None else None,
-
+            "serviceName": service_name if service_name is not None else "",
+            "servicePort": service_port if service_port is not None else None,
         }
         self._types = {
-            'serviceName': (str, None),
-            'servicePort': (int, None),
-
+            "serviceName": (str, None),
+            "servicePort": (int, None),
         }
 
     @property
@@ -449,34 +443,34 @@ class IngressBackend(_kuber_definitions.Definition):
         """
         Specifies the name of the referenced service.
         """
-        return self._properties.get('serviceName')
+        return typing.cast(
+            str,
+            self._properties.get("serviceName"),
+        )
 
     @service_name.setter
     def service_name(self, value: str):
         """
         Specifies the name of the referenced service.
         """
-        self._properties['serviceName'] = value
+        self._properties["serviceName"] = value
 
     @property
     def service_port(self) -> typing.Optional[int]:
         """
         Specifies the port of the referenced service.
         """
-        value = self._properties.get('servicePort')
+        value = self._properties.get("servicePort")
         return int(value) if value is not None else None
 
     @service_port.setter
-    def service_port(
-            self,
-            value: typing.Union[str, int, None]
-    ):
+    def service_port(self, value: typing.Union[str, int, None]):
         """
         Specifies the port of the referenced service.
         """
-        self._properties['servicePort'] = None if value is None else f'{value}'
+        self._properties["servicePort"] = None if value is None else f"{value}"
 
-    def __enter__(self) -> 'IngressBackend':
+    def __enter__(self) -> "IngressBackend":
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
@@ -489,84 +483,89 @@ class IngressList(_kuber_definitions.Collection):
     """
 
     def __init__(
-            self,
-            items: typing.List['Ingress'] = None,
-            metadata: 'ListMeta' = None,
+        self,
+        items: typing.List["Ingress"] = None,
+        metadata: "ListMeta" = None,
     ):
         """Create IngressList instance."""
         super(IngressList, self).__init__(
-            api_version='networking/v1beta1',
-            kind='IngressList'
+            api_version="networking/v1beta1", kind="IngressList"
         )
         self._properties = {
-            'items': items if items is not None else [],
-            'metadata': metadata if metadata is not None else ListMeta(),
-
+            "items": items if items is not None else [],
+            "metadata": metadata if metadata is not None else ListMeta(),
         }
         self._types = {
-            'apiVersion': (str, None),
-            'items': (list, Ingress),
-            'kind': (str, None),
-            'metadata': (ListMeta, None),
-
+            "apiVersion": (str, None),
+            "items": (list, Ingress),
+            "kind": (str, None),
+            "metadata": (ListMeta, None),
         }
 
     @property
-    def items(self) -> typing.List['Ingress']:
+    def items(self) -> typing.List["Ingress"]:
         """
         Items is the list of Ingress.
         """
-        return self._properties.get('items')
+        return typing.cast(
+            typing.List["Ingress"],
+            self._properties.get("items"),
+        )
 
     @items.setter
-    def items(
-            self,
-            value: typing.Union[typing.List['Ingress'], typing.List[dict]]
-    ):
+    def items(self, value: typing.Union[typing.List["Ingress"], typing.List[dict]]):
         """
         Items is the list of Ingress.
         """
-        cleaned = []
+        cleaned: typing.List[Ingress] = []
         for item in value:
             if isinstance(item, dict):
-                item = Ingress().from_dict(item)
-            cleaned.append(item)
-        self._properties['items'] = cleaned
+                item = typing.cast(
+                    Ingress,
+                    Ingress().from_dict(item),
+                )
+            cleaned.append(typing.cast(Ingress, item))
+        self._properties["items"] = cleaned
 
     @property
-    def metadata(self) -> 'ListMeta':
+    def metadata(self) -> "ListMeta":
         """
         Standard object's metadata. More info:
         https://git.k8s.io/community/contributors/devel/api-
         conventions.md#metadata
         """
-        return self._properties.get('metadata')
+        return typing.cast(
+            "ListMeta",
+            self._properties.get("metadata"),
+        )
 
     @metadata.setter
-    def metadata(self, value: typing.Union['ListMeta', dict]):
+    def metadata(self, value: typing.Union["ListMeta", dict]):
         """
         Standard object's metadata. More info:
         https://git.k8s.io/community/contributors/devel/api-
         conventions.md#metadata
         """
         if isinstance(value, dict):
-            value = ListMeta().from_dict(value)
-        self._properties['metadata'] = value
+            value = typing.cast(
+                ListMeta,
+                ListMeta().from_dict(value),
+            )
+        self._properties["metadata"] = value
 
     @staticmethod
     def get_resource_api(
-            api_client: client.ApiClient = None,
-            **kwargs
-    ) -> 'client.NetworkingV1beta1Api':
+        api_client: client.ApiClient = None, **kwargs
+    ) -> "client.NetworkingV1beta1Api":
         """
         Returns an instance of the kubernetes API client associated with
         this object.
         """
         if api_client:
-            kwargs['apl_client'] = api_client
+            kwargs["apl_client"] = api_client
         return client.NetworkingV1beta1Api(**kwargs)
 
-    def __enter__(self) -> 'IngressList':
+    def __enter__(self) -> "IngressList":
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
@@ -583,24 +582,21 @@ class IngressRule(_kuber_definitions.Definition):
     """
 
     def __init__(
-            self,
-            host: str = None,
-            http: 'HTTPIngressRuleValue' = None,
+        self,
+        host: str = None,
+        http: "HTTPIngressRuleValue" = None,
     ):
         """Create IngressRule instance."""
         super(IngressRule, self).__init__(
-            api_version='networking/v1beta1',
-            kind='IngressRule'
+            api_version="networking/v1beta1", kind="IngressRule"
         )
         self._properties = {
-            'host': host if host is not None else '',
-            'http': http if http is not None else HTTPIngressRuleValue(),
-
+            "host": host if host is not None else "",
+            "http": http if http is not None else HTTPIngressRuleValue(),
         }
         self._types = {
-            'host': (str, None),
-            'http': (HTTPIngressRuleValue, None),
-
+            "host": (str, None),
+            "http": (HTTPIngressRuleValue, None),
         }
 
     @property
@@ -611,18 +607,21 @@ class IngressRule(_kuber_definitions.Definition):
         the "host" part of the URI as defined in the RFC: 1. IPs are
         not allowed. Currently an IngressRuleValue can only apply to
         the
-        	  IP in the Spec of the parent Ingress.
+                  IP in the Spec of the parent Ingress.
         2. The `:` delimiter is not respected because ports are not
         allowed.
-        	  Currently the port of an Ingress is implicitly :80 for
+                  Currently the port of an Ingress is implicitly :80 for
         http and
-        	  :443 for https.
+                  :443 for https.
         Both these may change in the future. Incoming requests are
         matched against the host before the IngressRuleValue. If the
         host is unspecified, the Ingress routes all traffic based on
         the specified IngressRuleValue.
         """
-        return self._properties.get('host')
+        return typing.cast(
+            str,
+            self._properties.get("host"),
+        )
 
     @host.setter
     def host(self, value: str):
@@ -632,36 +631,38 @@ class IngressRule(_kuber_definitions.Definition):
         the "host" part of the URI as defined in the RFC: 1. IPs are
         not allowed. Currently an IngressRuleValue can only apply to
         the
-        	  IP in the Spec of the parent Ingress.
+                  IP in the Spec of the parent Ingress.
         2. The `:` delimiter is not respected because ports are not
         allowed.
-        	  Currently the port of an Ingress is implicitly :80 for
+                  Currently the port of an Ingress is implicitly :80 for
         http and
-        	  :443 for https.
+                  :443 for https.
         Both these may change in the future. Incoming requests are
         matched against the host before the IngressRuleValue. If the
         host is unspecified, the Ingress routes all traffic based on
         the specified IngressRuleValue.
         """
-        self._properties['host'] = value
+        self._properties["host"] = value
 
     @property
-    def http(self) -> 'HTTPIngressRuleValue':
-        """
-
-        """
-        return self._properties.get('http')
+    def http(self) -> "HTTPIngressRuleValue":
+        """"""
+        return typing.cast(
+            "HTTPIngressRuleValue",
+            self._properties.get("http"),
+        )
 
     @http.setter
-    def http(self, value: typing.Union['HTTPIngressRuleValue', dict]):
-        """
-
-        """
+    def http(self, value: typing.Union["HTTPIngressRuleValue", dict]):
+        """"""
         if isinstance(value, dict):
-            value = HTTPIngressRuleValue().from_dict(value)
-        self._properties['http'] = value
+            value = typing.cast(
+                HTTPIngressRuleValue,
+                HTTPIngressRuleValue().from_dict(value),
+            )
+        self._properties["http"] = value
 
-    def __enter__(self) -> 'IngressRule':
+    def __enter__(self) -> "IngressRule":
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
@@ -674,41 +675,41 @@ class IngressSpec(_kuber_definitions.Definition):
     """
 
     def __init__(
-            self,
-            backend: 'IngressBackend' = None,
-            rules: typing.List['IngressRule'] = None,
-            tls: typing.List['IngressTLS'] = None,
+        self,
+        backend: "IngressBackend" = None,
+        rules: typing.List["IngressRule"] = None,
+        tls: typing.List["IngressTLS"] = None,
     ):
         """Create IngressSpec instance."""
         super(IngressSpec, self).__init__(
-            api_version='networking/v1beta1',
-            kind='IngressSpec'
+            api_version="networking/v1beta1", kind="IngressSpec"
         )
         self._properties = {
-            'backend': backend if backend is not None else IngressBackend(),
-            'rules': rules if rules is not None else [],
-            'tls': tls if tls is not None else [],
-
+            "backend": backend if backend is not None else IngressBackend(),
+            "rules": rules if rules is not None else [],
+            "tls": tls if tls is not None else [],
         }
         self._types = {
-            'backend': (IngressBackend, None),
-            'rules': (list, IngressRule),
-            'tls': (list, IngressTLS),
-
+            "backend": (IngressBackend, None),
+            "rules": (list, IngressRule),
+            "tls": (list, IngressTLS),
         }
 
     @property
-    def backend(self) -> 'IngressBackend':
+    def backend(self) -> "IngressBackend":
         """
         A default backend capable of servicing requests that don't
         match any rule. At least one of 'backend' or 'rules' must be
         specified. This field is optional to allow the loadbalancer
         controller or defaulting logic to specify a global default.
         """
-        return self._properties.get('backend')
+        return typing.cast(
+            "IngressBackend",
+            self._properties.get("backend"),
+        )
 
     @backend.setter
-    def backend(self, value: typing.Union['IngressBackend', dict]):
+    def backend(self, value: typing.Union["IngressBackend", dict]):
         """
         A default backend capable of servicing requests that don't
         match any rule. At least one of 'backend' or 'rules' must be
@@ -716,37 +717,43 @@ class IngressSpec(_kuber_definitions.Definition):
         controller or defaulting logic to specify a global default.
         """
         if isinstance(value, dict):
-            value = IngressBackend().from_dict(value)
-        self._properties['backend'] = value
+            value = typing.cast(
+                IngressBackend,
+                IngressBackend().from_dict(value),
+            )
+        self._properties["backend"] = value
 
     @property
-    def rules(self) -> typing.List['IngressRule']:
+    def rules(self) -> typing.List["IngressRule"]:
         """
         A list of host rules used to configure the Ingress. If
         unspecified, or no rule matches, all traffic is sent to the
         default backend.
         """
-        return self._properties.get('rules')
+        return typing.cast(
+            typing.List["IngressRule"],
+            self._properties.get("rules"),
+        )
 
     @rules.setter
-    def rules(
-            self,
-            value: typing.Union[typing.List['IngressRule'], typing.List[dict]]
-    ):
+    def rules(self, value: typing.Union[typing.List["IngressRule"], typing.List[dict]]):
         """
         A list of host rules used to configure the Ingress. If
         unspecified, or no rule matches, all traffic is sent to the
         default backend.
         """
-        cleaned = []
+        cleaned: typing.List[IngressRule] = []
         for item in value:
             if isinstance(item, dict):
-                item = IngressRule().from_dict(item)
-            cleaned.append(item)
-        self._properties['rules'] = cleaned
+                item = typing.cast(
+                    IngressRule,
+                    IngressRule().from_dict(item),
+                )
+            cleaned.append(typing.cast(IngressRule, item))
+        self._properties["rules"] = cleaned
 
     @property
-    def tls(self) -> typing.List['IngressTLS']:
+    def tls(self) -> typing.List["IngressTLS"]:
         """
         TLS configuration. Currently the Ingress only supports a
         single TLS port, 443. If multiple members of this list
@@ -755,13 +762,13 @@ class IngressSpec(_kuber_definitions.Definition):
         SNI TLS extension, if the ingress controller fulfilling the
         ingress supports SNI.
         """
-        return self._properties.get('tls')
+        return typing.cast(
+            typing.List["IngressTLS"],
+            self._properties.get("tls"),
+        )
 
     @tls.setter
-    def tls(
-            self,
-            value: typing.Union[typing.List['IngressTLS'], typing.List[dict]]
-    ):
+    def tls(self, value: typing.Union[typing.List["IngressTLS"], typing.List[dict]]):
         """
         TLS configuration. Currently the Ingress only supports a
         single TLS port, 443. If multiple members of this list
@@ -770,14 +777,17 @@ class IngressSpec(_kuber_definitions.Definition):
         SNI TLS extension, if the ingress controller fulfilling the
         ingress supports SNI.
         """
-        cleaned = []
+        cleaned: typing.List[IngressTLS] = []
         for item in value:
             if isinstance(item, dict):
-                item = IngressTLS().from_dict(item)
-            cleaned.append(item)
-        self._properties['tls'] = cleaned
+                item = typing.cast(
+                    IngressTLS,
+                    IngressTLS().from_dict(item),
+                )
+            cleaned.append(typing.cast(IngressTLS, item))
+        self._properties["tls"] = cleaned
 
-    def __enter__(self) -> 'IngressSpec':
+    def __enter__(self) -> "IngressSpec":
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
@@ -790,42 +800,47 @@ class IngressStatus(_kuber_definitions.Definition):
     """
 
     def __init__(
-            self,
-            load_balancer: 'LoadBalancerStatus' = None,
+        self,
+        load_balancer: "LoadBalancerStatus" = None,
     ):
         """Create IngressStatus instance."""
         super(IngressStatus, self).__init__(
-            api_version='networking/v1beta1',
-            kind='IngressStatus'
+            api_version="networking/v1beta1", kind="IngressStatus"
         )
         self._properties = {
-            'loadBalancer': load_balancer if load_balancer is not None else LoadBalancerStatus(),
-
+            "loadBalancer": load_balancer
+            if load_balancer is not None
+            else LoadBalancerStatus(),
         }
         self._types = {
-            'loadBalancer': (LoadBalancerStatus, None),
-
+            "loadBalancer": (LoadBalancerStatus, None),
         }
 
     @property
-    def load_balancer(self) -> 'LoadBalancerStatus':
+    def load_balancer(self) -> "LoadBalancerStatus":
         """
         LoadBalancer contains the current status of the load-
         balancer.
         """
-        return self._properties.get('loadBalancer')
+        return typing.cast(
+            "LoadBalancerStatus",
+            self._properties.get("loadBalancer"),
+        )
 
     @load_balancer.setter
-    def load_balancer(self, value: typing.Union['LoadBalancerStatus', dict]):
+    def load_balancer(self, value: typing.Union["LoadBalancerStatus", dict]):
         """
         LoadBalancer contains the current status of the load-
         balancer.
         """
         if isinstance(value, dict):
-            value = LoadBalancerStatus().from_dict(value)
-        self._properties['loadBalancer'] = value
+            value = typing.cast(
+                LoadBalancerStatus,
+                LoadBalancerStatus().from_dict(value),
+            )
+        self._properties["loadBalancer"] = value
 
-    def __enter__(self) -> 'IngressStatus':
+    def __enter__(self) -> "IngressStatus":
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
@@ -839,24 +854,21 @@ class IngressTLS(_kuber_definitions.Definition):
     """
 
     def __init__(
-            self,
-            hosts: typing.List[str] = None,
-            secret_name: str = None,
+        self,
+        hosts: typing.List[str] = None,
+        secret_name: str = None,
     ):
         """Create IngressTLS instance."""
         super(IngressTLS, self).__init__(
-            api_version='networking/v1beta1',
-            kind='IngressTLS'
+            api_version="networking/v1beta1", kind="IngressTLS"
         )
         self._properties = {
-            'hosts': hosts if hosts is not None else [],
-            'secretName': secret_name if secret_name is not None else '',
-
+            "hosts": hosts if hosts is not None else [],
+            "secretName": secret_name if secret_name is not None else "",
         }
         self._types = {
-            'hosts': (list, str),
-            'secretName': (str, None),
-
+            "hosts": (list, str),
+            "secretName": (str, None),
         }
 
     @property
@@ -868,7 +880,10 @@ class IngressTLS(_kuber_definitions.Definition):
         loadbalancer controller fulfilling this Ingress, if left
         unspecified.
         """
-        return self._properties.get('hosts')
+        return typing.cast(
+            typing.List[str],
+            self._properties.get("hosts"),
+        )
 
     @hosts.setter
     def hosts(self, value: typing.List[str]):
@@ -879,7 +894,7 @@ class IngressTLS(_kuber_definitions.Definition):
         loadbalancer controller fulfilling this Ingress, if left
         unspecified.
         """
-        self._properties['hosts'] = value
+        self._properties["hosts"] = value
 
     @property
     def secret_name(self) -> str:
@@ -891,7 +906,10 @@ class IngressTLS(_kuber_definitions.Definition):
         IngressRule, the SNI host is used for termination and value
         of the Host header is used for routing.
         """
-        return self._properties.get('secretName')
+        return typing.cast(
+            str,
+            self._properties.get("secretName"),
+        )
 
     @secret_name.setter
     def secret_name(self, value: str):
@@ -903,9 +921,9 @@ class IngressTLS(_kuber_definitions.Definition):
         IngressRule, the SNI host is used for termination and value
         of the Host header is used for routing.
         """
-        self._properties['secretName'] = value
+        self._properties["secretName"] = value
 
-    def __enter__(self) -> 'IngressTLS':
+    def __enter__(self) -> "IngressTLS":
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
