@@ -4,10 +4,10 @@ from kubernetes import client
 from kuber import kube_api as _kube_api
 
 from kuber import definitions as _kuber_definitions
-from kuber.v1_14.meta_v1 import ListMeta
-from kuber.v1_14.meta_v1 import ObjectMeta
-from kuber.v1_14.meta_v1 import Status
-from kuber.v1_14.meta_v1 import StatusDetails
+from kuber.v1_19.meta_v1 import ListMeta
+from kuber.v1_19.meta_v1 import ObjectMeta
+from kuber.v1_19.meta_v1 import Status
+from kuber.v1_19.meta_v1 import StatusDetails
 
 
 class TokenReview(_kuber_definitions.Resource):
@@ -18,251 +18,238 @@ class TokenReview(_kuber_definitions.Resource):
     """
 
     def __init__(
-            self,
-            metadata: 'ObjectMeta' = None,
-            spec: 'TokenReviewSpec' = None,
-            status: 'TokenReviewStatus' = None,
+        self,
+        metadata: "ObjectMeta" = None,
+        spec: "TokenReviewSpec" = None,
+        status: "TokenReviewStatus" = None,
     ):
         """Create TokenReview instance."""
         super(TokenReview, self).__init__(
-            api_version='authentication/v1beta1',
-            kind='TokenReview'
+            api_version="authentication/v1beta1", kind="TokenReview"
         )
         self._properties = {
-            'metadata': metadata if metadata is not None else ObjectMeta(),
-            'spec': spec if spec is not None else TokenReviewSpec(),
-            'status': status if status is not None else TokenReviewStatus(),
-
+            "metadata": metadata if metadata is not None else ObjectMeta(),
+            "spec": spec if spec is not None else TokenReviewSpec(),
+            "status": status if status is not None else TokenReviewStatus(),
         }
         self._types = {
-            'apiVersion': (str, None),
-            'kind': (str, None),
-            'metadata': (ObjectMeta, None),
-            'spec': (TokenReviewSpec, None),
-            'status': (TokenReviewStatus, None),
-
+            "apiVersion": (str, None),
+            "kind": (str, None),
+            "metadata": (ObjectMeta, None),
+            "spec": (TokenReviewSpec, None),
+            "status": (TokenReviewStatus, None),
         }
 
     @property
-    def metadata(self) -> 'ObjectMeta':
-        """
-
-        """
-        return self._properties.get('metadata')
+    def metadata(self) -> "ObjectMeta":
+        """"""
+        return typing.cast(
+            "ObjectMeta",
+            self._properties.get("metadata"),
+        )
 
     @metadata.setter
-    def metadata(self, value: typing.Union['ObjectMeta', dict]):
-        """
-
-        """
+    def metadata(self, value: typing.Union["ObjectMeta", dict]):
+        """"""
         if isinstance(value, dict):
-            value = ObjectMeta().from_dict(value)
-        self._properties['metadata'] = value
+            value = typing.cast(
+                ObjectMeta,
+                ObjectMeta().from_dict(value),
+            )
+        self._properties["metadata"] = value
 
     @property
-    def spec(self) -> 'TokenReviewSpec':
+    def spec(self) -> "TokenReviewSpec":
         """
         Spec holds information about the request being evaluated
         """
-        return self._properties.get('spec')
+        return typing.cast(
+            "TokenReviewSpec",
+            self._properties.get("spec"),
+        )
 
     @spec.setter
-    def spec(self, value: typing.Union['TokenReviewSpec', dict]):
+    def spec(self, value: typing.Union["TokenReviewSpec", dict]):
         """
         Spec holds information about the request being evaluated
         """
         if isinstance(value, dict):
-            value = TokenReviewSpec().from_dict(value)
-        self._properties['spec'] = value
+            value = typing.cast(
+                TokenReviewSpec,
+                TokenReviewSpec().from_dict(value),
+            )
+        self._properties["spec"] = value
 
     @property
-    def status(self) -> 'TokenReviewStatus':
+    def status(self) -> "TokenReviewStatus":
         """
         Status is filled in by the server and indicates whether the
         request can be authenticated.
         """
-        return self._properties.get('status')
+        return typing.cast(
+            "TokenReviewStatus",
+            self._properties.get("status"),
+        )
 
     @status.setter
-    def status(self, value: typing.Union['TokenReviewStatus', dict]):
+    def status(self, value: typing.Union["TokenReviewStatus", dict]):
         """
         Status is filled in by the server and indicates whether the
         request can be authenticated.
         """
         if isinstance(value, dict):
-            value = TokenReviewStatus().from_dict(value)
-        self._properties['status'] = value
+            value = typing.cast(
+                TokenReviewStatus,
+                TokenReviewStatus().from_dict(value),
+            )
+        self._properties["status"] = value
 
-    def create_resource(
-            self,
-            namespace: 'str' = None
-    ) -> 'TokenReviewStatus':
+    def create_resource(self, namespace: "str" = None) -> "TokenReviewStatus":
         """
         Creates the TokenReview in the currently
         configured Kubernetes cluster and returns the status information
         returned by the Kubernetes API after the create is complete.
         """
-        names = [
-            'create_namespaced_token_review',
-            'create_token_review'
-        ]
+        names = ["create_namespaced_token_review", "create_token_review"]
 
         response = _kube_api.execute(
-            action='create',
+            action="create",
             resource=self,
             names=names,
             namespace=namespace,
             api_client=None,
-            api_args={'body': self.to_dict()}
-        )
-        return (
-            TokenReviewStatus()
-            .from_dict(_kube_api.to_kuber_dict(response.status))
+            api_args={"body": self.to_dict()},
         )
 
-    def replace_resource(
-            self,
-            namespace: 'str' = None
-    ) -> 'TokenReviewStatus':
+        output = TokenReviewStatus()
+        if response is not None:
+            output.from_dict(_kube_api.to_kuber_dict(response.status))
+        return output
+
+    def replace_resource(self, namespace: "str" = None) -> "TokenReviewStatus":
         """
         Replaces the TokenReview in the currently
         configured Kubernetes cluster and returns the status information
         returned by the Kubernetes API after the replace is complete.
         """
-        names = [
-            'replace_namespaced_token_review',
-            'replace_token_review'
-        ]
+        names = ["replace_namespaced_token_review", "replace_token_review"]
 
         response = _kube_api.execute(
-            action='replace',
+            action="replace",
             resource=self,
             names=names,
             namespace=namespace,
             api_client=None,
-            api_args={'body': self.to_dict(), 'name': self.metadata.name}
-        )
-        return (
-            TokenReviewStatus()
-            .from_dict(_kube_api.to_kuber_dict(response.status))
+            api_args={"body": self.to_dict(), "name": self.metadata.name},
         )
 
-    def patch_resource(
-            self,
-            namespace: 'str' = None
-    ) -> 'TokenReviewStatus':
+        output = TokenReviewStatus()
+        if response is not None:
+            output.from_dict(_kube_api.to_kuber_dict(response.status))
+        return output
+
+    def patch_resource(self, namespace: "str" = None) -> "TokenReviewStatus":
         """
         Patches the TokenReview in the currently
         configured Kubernetes cluster and returns the status information
         returned by the Kubernetes API after the replace is complete.
         """
-        names = [
-            'patch_namespaced_token_review',
-            'patch_token_review'
-        ]
+        names = ["patch_namespaced_token_review", "patch_token_review"]
 
         response = _kube_api.execute(
-            action='patch',
+            action="patch",
             resource=self,
             names=names,
             namespace=namespace,
             api_client=None,
-            api_args={'body': self.to_dict(), 'name': self.metadata.name}
-        )
-        return (
-            TokenReviewStatus()
-            .from_dict(_kube_api.to_kuber_dict(response.status))
+            api_args={"body": self.to_dict(), "name": self.metadata.name},
         )
 
-    def get_resource_status(
-            self,
-            namespace: 'str' = None
-    ) -> 'TokenReviewStatus':
+        output = TokenReviewStatus()
+        if response is not None:
+            output.from_dict(_kube_api.to_kuber_dict(response.status))
+        return output
+
+    def get_resource_status(self, namespace: "str" = None) -> "TokenReviewStatus":
         """
         Returns status information about the given resource within the cluster.
         """
-        names = [
-            'read_namespaced_token_review',
-            'read_token_review'
-        ]
+        names = ["read_namespaced_token_review", "read_token_review"]
 
         response = _kube_api.execute(
-            action='read',
+            action="read",
             resource=self,
             names=names,
             namespace=namespace,
             api_client=None,
-            api_args={'name': self.metadata.name}
-        )
-        return (
-            TokenReviewStatus()
-            .from_dict(_kube_api.to_kuber_dict(response.status))
+            api_args={"name": self.metadata.name},
         )
 
-    def read_resource(
-            self,
-            namespace: str = None
-    ):
+        output = TokenReviewStatus()
+        if response is not None:
+            output.from_dict(_kube_api.to_kuber_dict(response.status))
+        return output
+
+    def read_resource(self, namespace: str = None):
         """
         Reads the TokenReview from the currently configured
         Kubernetes cluster and returns the low-level definition object.
         """
         names = [
-            'read_namespaced_token_review',
-            'read_token_review'
+            "read_namespaced_token_review",
+            "read_token_review",
         ]
         return _kube_api.execute(
-            action='read',
+            action="read",
             resource=self,
             names=names,
             namespace=namespace,
             api_client=None,
-            api_args={'name': self.metadata.name}
+            api_args={"name": self.metadata.name},
         )
 
     def delete_resource(
-            self,
-            namespace: str = None,
-            propagation_policy: str = 'Foreground',
-            grace_period_seconds: int = 10
+        self,
+        namespace: str = None,
+        propagation_policy: str = "Foreground",
+        grace_period_seconds: int = 10,
     ):
         """
         Deletes the TokenReview from the currently configured
         Kubernetes cluster.
         """
         names = [
-            'delete_namespaced_token_review',
-            'delete_token_review'
+            "delete_namespaced_token_review",
+            "delete_token_review",
         ]
 
         body = client.V1DeleteOptions(
             propagation_policy=propagation_policy,
-            grace_period_seconds=grace_period_seconds
+            grace_period_seconds=grace_period_seconds,
         )
 
         _kube_api.execute(
-            action='delete',
+            action="delete",
             resource=self,
             names=names,
             namespace=namespace,
             api_client=None,
-            api_args={'name': self.metadata.name, 'body': body}
+            api_args={"name": self.metadata.name, "body": body},
         )
 
     @staticmethod
     def get_resource_api(
-            api_client: client.ApiClient = None,
-            **kwargs
-    ) -> 'client.AuthenticationV1beta1Api':
+        api_client: client.ApiClient = None, **kwargs
+    ) -> "client.AuthenticationV1beta1Api":
         """
         Returns an instance of the kubernetes API client associated with
         this object.
         """
         if api_client:
-            kwargs['apl_client'] = api_client
+            kwargs["apl_client"] = api_client
         return client.AuthenticationV1beta1Api(**kwargs)
 
-    def __enter__(self) -> 'TokenReview':
+    def __enter__(self) -> "TokenReview":
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
@@ -276,24 +263,21 @@ class TokenReviewSpec(_kuber_definitions.Definition):
     """
 
     def __init__(
-            self,
-            audiences: typing.List[str] = None,
-            token: str = None,
+        self,
+        audiences: typing.List[str] = None,
+        token: str = None,
     ):
         """Create TokenReviewSpec instance."""
         super(TokenReviewSpec, self).__init__(
-            api_version='authentication/v1beta1',
-            kind='TokenReviewSpec'
+            api_version="authentication/v1beta1", kind="TokenReviewSpec"
         )
         self._properties = {
-            'audiences': audiences if audiences is not None else [],
-            'token': token if token is not None else '',
-
+            "audiences": audiences if audiences is not None else [],
+            "token": token if token is not None else "",
         }
         self._types = {
-            'audiences': (list, str),
-            'token': (str, None),
-
+            "audiences": (list, str),
+            "token": (str, None),
         }
 
     @property
@@ -306,7 +290,10 @@ class TokenReviewSpec(_kuber_definitions.Definition):
         no audiences are provided, the audience will default to the
         audience of the Kubernetes apiserver.
         """
-        return self._properties.get('audiences')
+        return typing.cast(
+            typing.List[str],
+            self._properties.get("audiences"),
+        )
 
     @audiences.setter
     def audiences(self, value: typing.List[str]):
@@ -318,23 +305,26 @@ class TokenReviewSpec(_kuber_definitions.Definition):
         no audiences are provided, the audience will default to the
         audience of the Kubernetes apiserver.
         """
-        self._properties['audiences'] = value
+        self._properties["audiences"] = value
 
     @property
     def token(self) -> str:
         """
         Token is the opaque bearer token.
         """
-        return self._properties.get('token')
+        return typing.cast(
+            str,
+            self._properties.get("token"),
+        )
 
     @token.setter
     def token(self, value: str):
         """
         Token is the opaque bearer token.
         """
-        self._properties['token'] = value
+        self._properties["token"] = value
 
-    def __enter__(self) -> 'TokenReviewSpec':
+    def __enter__(self) -> "TokenReviewSpec":
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
@@ -348,30 +338,27 @@ class TokenReviewStatus(_kuber_definitions.Definition):
     """
 
     def __init__(
-            self,
-            audiences: typing.List[str] = None,
-            authenticated: bool = None,
-            error: str = None,
-            user: 'UserInfo' = None,
+        self,
+        audiences: typing.List[str] = None,
+        authenticated: bool = None,
+        error: str = None,
+        user: "UserInfo" = None,
     ):
         """Create TokenReviewStatus instance."""
         super(TokenReviewStatus, self).__init__(
-            api_version='authentication/v1beta1',
-            kind='TokenReviewStatus'
+            api_version="authentication/v1beta1", kind="TokenReviewStatus"
         )
         self._properties = {
-            'audiences': audiences if audiences is not None else [],
-            'authenticated': authenticated if authenticated is not None else None,
-            'error': error if error is not None else '',
-            'user': user if user is not None else UserInfo(),
-
+            "audiences": audiences if audiences is not None else [],
+            "authenticated": authenticated if authenticated is not None else None,
+            "error": error if error is not None else "",
+            "user": user if user is not None else UserInfo(),
         }
         self._types = {
-            'audiences': (list, str),
-            'authenticated': (bool, None),
-            'error': (str, None),
-            'user': (UserInfo, None),
-
+            "audiences": (list, str),
+            "authenticated": (bool, None),
+            "error": (str, None),
+            "user": (UserInfo, None),
         }
 
     @property
@@ -389,7 +376,10 @@ class TokenReviewStatus(_kuber_definitions.Definition):
         field where status.authenticated is "true", the token is
         valid against the audience of the Kubernetes API server.
         """
-        return self._properties.get('audiences')
+        return typing.cast(
+            typing.List[str],
+            self._properties.get("audiences"),
+        )
 
     @audiences.setter
     def audiences(self, value: typing.List[str]):
@@ -406,7 +396,7 @@ class TokenReviewStatus(_kuber_definitions.Definition):
         field where status.authenticated is "true", the token is
         valid against the audience of the Kubernetes API server.
         """
-        self._properties['audiences'] = value
+        self._properties["audiences"] = value
 
     @property
     def authenticated(self) -> bool:
@@ -414,7 +404,10 @@ class TokenReviewStatus(_kuber_definitions.Definition):
         Authenticated indicates that the token was associated with a
         known user.
         """
-        return self._properties.get('authenticated')
+        return typing.cast(
+            bool,
+            self._properties.get("authenticated"),
+        )
 
     @authenticated.setter
     def authenticated(self, value: bool):
@@ -422,39 +415,48 @@ class TokenReviewStatus(_kuber_definitions.Definition):
         Authenticated indicates that the token was associated with a
         known user.
         """
-        self._properties['authenticated'] = value
+        self._properties["authenticated"] = value
 
     @property
     def error(self) -> str:
         """
         Error indicates that the token couldn't be checked
         """
-        return self._properties.get('error')
+        return typing.cast(
+            str,
+            self._properties.get("error"),
+        )
 
     @error.setter
     def error(self, value: str):
         """
         Error indicates that the token couldn't be checked
         """
-        self._properties['error'] = value
+        self._properties["error"] = value
 
     @property
-    def user(self) -> 'UserInfo':
+    def user(self) -> "UserInfo":
         """
         User is the UserInfo associated with the provided token.
         """
-        return self._properties.get('user')
+        return typing.cast(
+            "UserInfo",
+            self._properties.get("user"),
+        )
 
     @user.setter
-    def user(self, value: typing.Union['UserInfo', dict]):
+    def user(self, value: typing.Union["UserInfo", dict]):
         """
         User is the UserInfo associated with the provided token.
         """
         if isinstance(value, dict):
-            value = UserInfo().from_dict(value)
-        self._properties['user'] = value
+            value = typing.cast(
+                UserInfo,
+                UserInfo().from_dict(value),
+            )
+        self._properties["user"] = value
 
-    def __enter__(self) -> 'TokenReviewStatus':
+    def __enter__(self) -> "TokenReviewStatus":
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
@@ -468,30 +470,27 @@ class UserInfo(_kuber_definitions.Definition):
     """
 
     def __init__(
-            self,
-            extra: dict = None,
-            groups: typing.List[str] = None,
-            uid: str = None,
-            username: str = None,
+        self,
+        extra: dict = None,
+        groups: typing.List[str] = None,
+        uid: str = None,
+        username: str = None,
     ):
         """Create UserInfo instance."""
         super(UserInfo, self).__init__(
-            api_version='authentication/v1beta1',
-            kind='UserInfo'
+            api_version="authentication/v1beta1", kind="UserInfo"
         )
         self._properties = {
-            'extra': extra if extra is not None else {},
-            'groups': groups if groups is not None else [],
-            'uid': uid if uid is not None else '',
-            'username': username if username is not None else '',
-
+            "extra": extra if extra is not None else {},
+            "groups": groups if groups is not None else [],
+            "uid": uid if uid is not None else "",
+            "username": username if username is not None else "",
         }
         self._types = {
-            'extra': (dict, None),
-            'groups': (list, str),
-            'uid': (str, None),
-            'username': (str, None),
-
+            "extra": (dict, None),
+            "groups": (list, str),
+            "uid": (str, None),
+            "username": (str, None),
         }
 
     @property
@@ -499,28 +498,34 @@ class UserInfo(_kuber_definitions.Definition):
         """
         Any additional information provided by the authenticator.
         """
-        return self._properties.get('extra')
+        return typing.cast(
+            dict,
+            self._properties.get("extra"),
+        )
 
     @extra.setter
     def extra(self, value: dict):
         """
         Any additional information provided by the authenticator.
         """
-        self._properties['extra'] = value
+        self._properties["extra"] = value
 
     @property
     def groups(self) -> typing.List[str]:
         """
         The names of groups this user is a part of.
         """
-        return self._properties.get('groups')
+        return typing.cast(
+            typing.List[str],
+            self._properties.get("groups"),
+        )
 
     @groups.setter
     def groups(self, value: typing.List[str]):
         """
         The names of groups this user is a part of.
         """
-        self._properties['groups'] = value
+        self._properties["groups"] = value
 
     @property
     def uid(self) -> str:
@@ -529,7 +534,10 @@ class UserInfo(_kuber_definitions.Definition):
         this user is deleted and another user by the same name is
         added, they will have different UIDs.
         """
-        return self._properties.get('uid')
+        return typing.cast(
+            str,
+            self._properties.get("uid"),
+        )
 
     @uid.setter
     def uid(self, value: str):
@@ -538,7 +546,7 @@ class UserInfo(_kuber_definitions.Definition):
         this user is deleted and another user by the same name is
         added, they will have different UIDs.
         """
-        self._properties['uid'] = value
+        self._properties["uid"] = value
 
     @property
     def username(self) -> str:
@@ -546,7 +554,10 @@ class UserInfo(_kuber_definitions.Definition):
         The name that uniquely identifies this user among all active
         users.
         """
-        return self._properties.get('username')
+        return typing.cast(
+            str,
+            self._properties.get("username"),
+        )
 
     @username.setter
     def username(self, value: str):
@@ -554,9 +565,9 @@ class UserInfo(_kuber_definitions.Definition):
         The name that uniquely identifies this user among all active
         users.
         """
-        self._properties['username'] = value
+        self._properties["username"] = value
 
-    def __enter__(self) -> 'UserInfo':
+    def __enter__(self) -> "UserInfo":
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
