@@ -4,8 +4,8 @@ from kubernetes import client
 from kuber import kube_api as _kube_api
 
 from kuber import definitions as _kuber_definitions
-from kuber.v1_17.meta_v1 import ListMeta
-from kuber.v1_17.meta_v1 import ObjectMeta
+from kuber.v1_20.meta_v1 import ListMeta
+from kuber.v1_20.meta_v1 import ObjectMeta
 
 
 class PriorityClass(_kuber_definitions.Resource):
@@ -18,35 +18,34 @@ class PriorityClass(_kuber_definitions.Resource):
     """
 
     def __init__(
-            self,
-            description: str = None,
-            global_default: bool = None,
-            metadata: 'ObjectMeta' = None,
-            preemption_policy: str = None,
-            value: int = None,
+        self,
+        description: str = None,
+        global_default: bool = None,
+        metadata: "ObjectMeta" = None,
+        preemption_policy: str = None,
+        value: int = None,
     ):
         """Create PriorityClass instance."""
         super(PriorityClass, self).__init__(
-            api_version='scheduling/v1beta1',
-            kind='PriorityClass'
+            api_version="scheduling/v1beta1", kind="PriorityClass"
         )
         self._properties = {
-            'description': description if description is not None else '',
-            'globalDefault': global_default if global_default is not None else None,
-            'metadata': metadata if metadata is not None else ObjectMeta(),
-            'preemptionPolicy': preemption_policy if preemption_policy is not None else '',
-            'value': value if value is not None else None,
-
+            "description": description if description is not None else "",
+            "globalDefault": global_default if global_default is not None else None,
+            "metadata": metadata if metadata is not None else ObjectMeta(),
+            "preemptionPolicy": preemption_policy
+            if preemption_policy is not None
+            else "",
+            "value": value if value is not None else None,
         }
         self._types = {
-            'apiVersion': (str, None),
-            'description': (str, None),
-            'globalDefault': (bool, None),
-            'kind': (str, None),
-            'metadata': (ObjectMeta, None),
-            'preemptionPolicy': (str, None),
-            'value': (int, None),
-
+            "apiVersion": (str, None),
+            "description": (str, None),
+            "globalDefault": (bool, None),
+            "kind": (str, None),
+            "metadata": (ObjectMeta, None),
+            "preemptionPolicy": (str, None),
+            "value": (int, None),
         }
 
     @property
@@ -55,7 +54,10 @@ class PriorityClass(_kuber_definitions.Resource):
         description is an arbitrary string that usually provides
         guidelines on when this priority class should be used.
         """
-        return self._properties.get('description')
+        return typing.cast(
+            str,
+            self._properties.get("description"),
+        )
 
     @description.setter
     def description(self, value: str):
@@ -63,7 +65,7 @@ class PriorityClass(_kuber_definitions.Resource):
         description is an arbitrary string that usually provides
         guidelines on when this priority class should be used.
         """
-        self._properties['description'] = value
+        self._properties["description"] = value
 
     @property
     def global_default(self) -> bool:
@@ -76,7 +78,10 @@ class PriorityClass(_kuber_definitions.Resource):
         smallest value of such global default PriorityClasses will
         be used as the default priority.
         """
-        return self._properties.get('globalDefault')
+        return typing.cast(
+            bool,
+            self._properties.get("globalDefault"),
+        )
 
     @global_default.setter
     def global_default(self, value: bool):
@@ -89,49 +94,56 @@ class PriorityClass(_kuber_definitions.Resource):
         smallest value of such global default PriorityClasses will
         be used as the default priority.
         """
-        self._properties['globalDefault'] = value
+        self._properties["globalDefault"] = value
 
     @property
-    def metadata(self) -> 'ObjectMeta':
+    def metadata(self) -> "ObjectMeta":
         """
         Standard object's metadata. More info:
         https://git.k8s.io/community/contributors/devel/sig-
         architecture/api-conventions.md#metadata
         """
-        return self._properties.get('metadata')
+        return typing.cast(
+            "ObjectMeta",
+            self._properties.get("metadata"),
+        )
 
     @metadata.setter
-    def metadata(self, value: typing.Union['ObjectMeta', dict]):
+    def metadata(self, value: typing.Union["ObjectMeta", dict]):
         """
         Standard object's metadata. More info:
         https://git.k8s.io/community/contributors/devel/sig-
         architecture/api-conventions.md#metadata
         """
         if isinstance(value, dict):
-            value = ObjectMeta().from_dict(value)
-        self._properties['metadata'] = value
+            value = typing.cast(
+                ObjectMeta,
+                ObjectMeta().from_dict(value),
+            )
+        self._properties["metadata"] = value
 
     @property
     def preemption_policy(self) -> str:
         """
         PreemptionPolicy is the Policy for preempting pods with
         lower priority. One of Never, PreemptLowerPriority. Defaults
-        to PreemptLowerPriority if unset. This field is alpha-level
-        and is only honored by servers that enable the
-        NonPreemptingPriority feature.
+        to PreemptLowerPriority if unset. This field is beta-level,
+        gated by the NonPreemptingPriority feature-gate.
         """
-        return self._properties.get('preemptionPolicy')
+        return typing.cast(
+            str,
+            self._properties.get("preemptionPolicy"),
+        )
 
     @preemption_policy.setter
     def preemption_policy(self, value: str):
         """
         PreemptionPolicy is the Policy for preempting pods with
         lower priority. One of Never, PreemptLowerPriority. Defaults
-        to PreemptLowerPriority if unset. This field is alpha-level
-        and is only honored by servers that enable the
-        NonPreemptingPriority feature.
+        to PreemptLowerPriority if unset. This field is beta-level,
+        gated by the NonPreemptingPriority feature-gate.
         """
-        self._properties['preemptionPolicy'] = value
+        self._properties["preemptionPolicy"] = value
 
     @property
     def value(self) -> int:
@@ -140,7 +152,10 @@ class PriorityClass(_kuber_definitions.Resource):
         priority that pods receive when they have the name of this
         class in their pod spec.
         """
-        return self._properties.get('value')
+        return typing.cast(
+            int,
+            self._properties.get("value"),
+        )
 
     @value.setter
     def value(self, value: int):
@@ -149,133 +164,120 @@ class PriorityClass(_kuber_definitions.Resource):
         priority that pods receive when they have the name of this
         class in their pod spec.
         """
-        self._properties['value'] = value
+        self._properties["value"] = value
 
-    def create_resource(self, namespace: 'str' = None):
+    def create_resource(self, namespace: "str" = None):
         """
         Creates the PriorityClass in the currently
         configured Kubernetes cluster.
         """
-        names = [
-            'create_namespaced_priority_class',
-            'create_priority_class'
-        ]
+        names = ["create_namespaced_priority_class", "create_priority_class"]
 
         _kube_api.execute(
-            action='create',
+            action="create",
             resource=self,
             names=names,
             namespace=namespace,
             api_client=None,
-            api_args={'body': self.to_dict()}
+            api_args={"body": self.to_dict()},
         )
 
-    def replace_resource(self, namespace: 'str' = None):
+    def replace_resource(self, namespace: "str" = None):
         """
         Replaces the PriorityClass in the currently
         configured Kubernetes cluster.
         """
-        names = [
-            'replace_namespaced_priority_class',
-            'replace_priority_class'
-        ]
+        names = ["replace_namespaced_priority_class", "replace_priority_class"]
 
         _kube_api.execute(
-            action='replace',
+            action="replace",
             resource=self,
             names=names,
             namespace=namespace,
             api_client=None,
-            api_args={'body': self.to_dict(), 'name': self.metadata.name}
+            api_args={"body": self.to_dict(), "name": self.metadata.name},
         )
 
-    def patch_resource(self, namespace: 'str' = None):
+    def patch_resource(self, namespace: "str" = None):
         """
         Patches the PriorityClass in the currently
         configured Kubernetes cluster.
         """
-        names = [
-            'patch_namespaced_priority_class',
-            'patch_priority_class'
-        ]
+        names = ["patch_namespaced_priority_class", "patch_priority_class"]
 
         _kube_api.execute(
-            action='patch',
+            action="patch",
             resource=self,
             names=names,
             namespace=namespace,
             api_client=None,
-            api_args={'body': self.to_dict(), 'name': self.metadata.name}
+            api_args={"body": self.to_dict(), "name": self.metadata.name},
         )
 
-    def get_resource_status(self, namespace: 'str' = None):
+    def get_resource_status(self, namespace: "str" = None):
         """This resource does not have a status."""
         pass
 
-    def read_resource(
-            self,
-            namespace: str = None
-    ):
+    def read_resource(self, namespace: str = None):
         """
         Reads the PriorityClass from the currently configured
         Kubernetes cluster and returns the low-level definition object.
         """
         names = [
-            'read_namespaced_priority_class',
-            'read_priority_class'
+            "read_namespaced_priority_class",
+            "read_priority_class",
         ]
         return _kube_api.execute(
-            action='read',
+            action="read",
             resource=self,
             names=names,
             namespace=namespace,
             api_client=None,
-            api_args={'name': self.metadata.name}
+            api_args={"name": self.metadata.name},
         )
 
     def delete_resource(
-            self,
-            namespace: str = None,
-            propagation_policy: str = 'Foreground',
-            grace_period_seconds: int = 10
+        self,
+        namespace: str = None,
+        propagation_policy: str = "Foreground",
+        grace_period_seconds: int = 10,
     ):
         """
         Deletes the PriorityClass from the currently configured
         Kubernetes cluster.
         """
         names = [
-            'delete_namespaced_priority_class',
-            'delete_priority_class'
+            "delete_namespaced_priority_class",
+            "delete_priority_class",
         ]
 
         body = client.V1DeleteOptions(
             propagation_policy=propagation_policy,
-            grace_period_seconds=grace_period_seconds
+            grace_period_seconds=grace_period_seconds,
         )
 
         _kube_api.execute(
-            action='delete',
+            action="delete",
             resource=self,
             names=names,
             namespace=namespace,
             api_client=None,
-            api_args={'name': self.metadata.name, 'body': body}
+            api_args={"name": self.metadata.name, "body": body},
         )
 
     @staticmethod
     def get_resource_api(
-            api_client: client.ApiClient = None,
-            **kwargs
-    ) -> 'client.SchedulingV1beta1Api':
+        api_client: client.ApiClient = None, **kwargs
+    ) -> "client.SchedulingV1beta1Api":
         """
         Returns an instance of the kubernetes API client associated with
         this object.
         """
         if api_client:
-            kwargs['apl_client'] = api_client
+            kwargs["apl_client"] = api_client
         return client.SchedulingV1beta1Api(**kwargs)
 
-    def __enter__(self) -> 'PriorityClass':
+    def __enter__(self) -> "PriorityClass":
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
@@ -288,84 +290,91 @@ class PriorityClassList(_kuber_definitions.Collection):
     """
 
     def __init__(
-            self,
-            items: typing.List['PriorityClass'] = None,
-            metadata: 'ListMeta' = None,
+        self,
+        items: typing.List["PriorityClass"] = None,
+        metadata: "ListMeta" = None,
     ):
         """Create PriorityClassList instance."""
         super(PriorityClassList, self).__init__(
-            api_version='scheduling/v1beta1',
-            kind='PriorityClassList'
+            api_version="scheduling/v1beta1", kind="PriorityClassList"
         )
         self._properties = {
-            'items': items if items is not None else [],
-            'metadata': metadata if metadata is not None else ListMeta(),
-
+            "items": items if items is not None else [],
+            "metadata": metadata if metadata is not None else ListMeta(),
         }
         self._types = {
-            'apiVersion': (str, None),
-            'items': (list, PriorityClass),
-            'kind': (str, None),
-            'metadata': (ListMeta, None),
-
+            "apiVersion": (str, None),
+            "items": (list, PriorityClass),
+            "kind": (str, None),
+            "metadata": (ListMeta, None),
         }
 
     @property
-    def items(self) -> typing.List['PriorityClass']:
+    def items(self) -> typing.List["PriorityClass"]:
         """
         items is the list of PriorityClasses
         """
-        return self._properties.get('items')
+        return typing.cast(
+            typing.List["PriorityClass"],
+            self._properties.get("items"),
+        )
 
     @items.setter
     def items(
-            self,
-            value: typing.Union[typing.List['PriorityClass'], typing.List[dict]]
+        self, value: typing.Union[typing.List["PriorityClass"], typing.List[dict]]
     ):
         """
         items is the list of PriorityClasses
         """
-        cleaned = []
+        cleaned: typing.List[PriorityClass] = []
         for item in value:
             if isinstance(item, dict):
-                item = PriorityClass().from_dict(item)
-            cleaned.append(item)
-        self._properties['items'] = cleaned
+                item = typing.cast(
+                    PriorityClass,
+                    PriorityClass().from_dict(item),
+                )
+            cleaned.append(typing.cast(PriorityClass, item))
+        self._properties["items"] = cleaned
 
     @property
-    def metadata(self) -> 'ListMeta':
+    def metadata(self) -> "ListMeta":
         """
         Standard list metadata More info:
         https://git.k8s.io/community/contributors/devel/sig-
         architecture/api-conventions.md#metadata
         """
-        return self._properties.get('metadata')
+        return typing.cast(
+            "ListMeta",
+            self._properties.get("metadata"),
+        )
 
     @metadata.setter
-    def metadata(self, value: typing.Union['ListMeta', dict]):
+    def metadata(self, value: typing.Union["ListMeta", dict]):
         """
         Standard list metadata More info:
         https://git.k8s.io/community/contributors/devel/sig-
         architecture/api-conventions.md#metadata
         """
         if isinstance(value, dict):
-            value = ListMeta().from_dict(value)
-        self._properties['metadata'] = value
+            value = typing.cast(
+                ListMeta,
+                ListMeta().from_dict(value),
+            )
+        self._properties["metadata"] = value
 
     @staticmethod
     def get_resource_api(
-            api_client: client.ApiClient = None,
-            **kwargs
-    ) -> 'client.SchedulingV1beta1Api':
+        api_client: client.ApiClient = None, **kwargs
+    ) -> "client.SchedulingV1beta1Api":
         """
         Returns an instance of the kubernetes API client associated with
         this object.
         """
         if api_client:
-            kwargs['apl_client'] = api_client
+            kwargs["apl_client"] = api_client
         return client.SchedulingV1beta1Api(**kwargs)
 
-    def __enter__(self) -> 'PriorityClassList':
+    def __enter__(self) -> "PriorityClassList":
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
