@@ -6,13 +6,13 @@ from kuber import versioning
 # package and kuber metadata around its creation and labeling within the
 # kuber library.
 KUBERNETES_VERSION = versioning.KubernetesVersion(
-    label='v1.19',
-    version='v1.19.0-rc.2',
-    major='1',
-    minor='19',
-    patch='0',
-    pre_release='rc.2',
-    build='',
-    created_at=_datetime.datetime(2020, 7, 24),
-    commit_sha='27bb2a4a0a5cb8330178d19e57fa61fffa895c98'
+    label="v1.21",
+    version="v1.21.0-alpha.0",
+    major="1",
+    minor="21",
+    patch="0",
+    pre_release="alpha.0",
+    build="",
+    created_at=_datetime.datetime(2020, 12, 8),
+    commit_sha="98bc258bf5516b6c60860e06845b899eab29825d",
 )
